[Libreoffice-commits] core.git: 4 commits - sw/source
Miklos Vajna
vmiklos at collabora.co.uk
Tue Nov 10 23:57:23 PST 2015
sw/source/filter/ww8/ww8graf.cxx | 4
sw/source/filter/ww8/ww8par.cxx | 32 +--
sw/source/filter/ww8/ww8par.hxx | 114 +++++------
sw/source/filter/ww8/ww8par2.cxx | 136 ++++++-------
sw/source/filter/ww8/ww8par3.cxx | 44 ++--
sw/source/filter/ww8/ww8par6.cxx | 68 +++---
sw/source/ui/frmdlg/frmpage.cxx | 280 +++++++++++++--------------
sw/source/uibase/inc/frmpage.hxx | 54 ++---
sw/source/uibase/inc/redlndlg.hxx | 58 ++---
sw/source/uibase/inc/toxmgr.hxx | 182 +++++++++---------
sw/source/uibase/index/toxmgr.cxx | 10
sw/source/uibase/misc/redlndlg.cxx | 372 ++++++++++++++++++-------------------
12 files changed, 677 insertions(+), 677 deletions(-)
New commits:
commit fdeaa040059647f7bd1d103f2971e945bbe18659
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date: Wed Nov 11 08:56:22 2015 +0100
sw: prefix members of SwFrmAddPage
Change-Id: Id4a5a5794ff03a88922df7fd1dcba75ed601dd59
diff --git a/sw/source/ui/frmdlg/frmpage.cxx b/sw/source/ui/frmdlg/frmpage.cxx
index 81d391b..514be1b 100644
--- a/sw/source/ui/frmdlg/frmpage.cxx
+++ b/sw/source/ui/frmdlg/frmpage.cxx
@@ -2864,34 +2864,34 @@ IMPL_LINK_NOARG_TYPED(SwFrmURLPage, InsertFileHdl, Button*, void)
SwFrmAddPage::SwFrmAddPage(vcl::Window *pParent, const SfxItemSet &rSet)
: SfxTabPage(pParent, "FrmAddPage" , "modules/swriter/ui/frmaddpage.ui", &rSet)
- , pWrtSh(nullptr)
- , bHtmlMode(false)
- , bFormat(false)
- , bNew(false)
-{
- get(pNameFrame, "nameframe");
- get(pNameFT,"name_label");
- get(pNameED,"name");
- get(pAltNameFT,"altname_label");
- get(pAltNameED,"altname");
- get(pPrevFT,"prev_label");
- get(pPrevLB,"prev");
- get(pNextFT,"next_label");
- get(pNextLB,"next");
-
- get(pProtectFrame,"protect");
- get(pProtectContentCB,"protectcontent");
- get(pProtectFrameCB,"protectframe");
- get(pProtectSizeCB,"protectsize");
+ , m_pWrtSh(nullptr)
+ , m_bHtmlMode(false)
+ , m_bFormat(false)
+ , m_bNew(false)
+{
+ get(m_pNameFrame, "nameframe");
+ get(m_pNameFT,"name_label");
+ get(m_pNameED,"name");
+ get(m_pAltNameFT,"altname_label");
+ get(m_pAltNameED,"altname");
+ get(m_pPrevFT,"prev_label");
+ get(m_pPrevLB,"prev");
+ get(m_pNextFT,"next_label");
+ get(m_pNextLB,"next");
+
+ get(m_pProtectFrame,"protect");
+ get(m_pProtectContentCB,"protectcontent");
+ get(m_pProtectFrameCB,"protectframe");
+ get(m_pProtectSizeCB,"protectsize");
get(m_pContentAlignFrame, "contentalign");
get(m_pVertAlignLB,"vertalign");
- get(pPropertiesFrame,"properties");
- get(pEditInReadonlyCB,"editinreadonly");
- get(pPrintFrameCB,"printframe");
- get(pTextFlowFT,"textflow_label");
- get(pTextFlowLB,"textflow");
+ get(m_pPropertiesFrame,"properties");
+ get(m_pEditInReadonlyCB,"editinreadonly");
+ get(m_pPrintFrameCB,"printframe");
+ get(m_pTextFlowFT,"textflow_label");
+ get(m_pTextFlowLB,"textflow");
}
@@ -2902,26 +2902,26 @@ SwFrmAddPage::~SwFrmAddPage()
void SwFrmAddPage::dispose()
{
- pNameFrame.clear();
- pNameFT.clear();
- pNameED.clear();
- pAltNameFT.clear();
- pAltNameED.clear();
- pPrevFT.clear();
- pPrevLB.clear();
- pNextFT.clear();
- pNextLB.clear();
- pProtectFrame.clear();
- pProtectContentCB.clear();
- pProtectFrameCB.clear();
- pProtectSizeCB.clear();
+ m_pNameFrame.clear();
+ m_pNameFT.clear();
+ m_pNameED.clear();
+ m_pAltNameFT.clear();
+ m_pAltNameED.clear();
+ m_pPrevFT.clear();
+ m_pPrevLB.clear();
+ m_pNextFT.clear();
+ m_pNextLB.clear();
+ m_pProtectFrame.clear();
+ m_pProtectContentCB.clear();
+ m_pProtectFrameCB.clear();
+ m_pProtectSizeCB.clear();
m_pContentAlignFrame.clear();
m_pVertAlignLB.clear();
- pPropertiesFrame.clear();
- pEditInReadonlyCB.clear();
- pPrintFrameCB.clear();
- pTextFlowFT.clear();
- pTextFlowLB.clear();
+ m_pPropertiesFrame.clear();
+ m_pEditInReadonlyCB.clear();
+ m_pPrintFrameCB.clear();
+ m_pTextFlowFT.clear();
+ m_pTextFlowLB.clear();
SfxTabPage::dispose();
}
@@ -2935,30 +2935,30 @@ void SwFrmAddPage::Reset(const SfxItemSet *rSet )
{
const SfxPoolItem* pItem;
sal_uInt16 nHtmlMode = ::GetHtmlMode(static_cast<const SwDocShell*>(SfxObjectShell::Current()));
- bHtmlMode = (nHtmlMode & HTMLMODE_ON) != 0;
- if (bHtmlMode)
+ m_bHtmlMode = (nHtmlMode & HTMLMODE_ON) != 0;
+ if (m_bHtmlMode)
{
- pProtectFrame->Hide();
- pEditInReadonlyCB->Hide();
- pPrintFrameCB->Hide();
+ m_pProtectFrame->Hide();
+ m_pEditInReadonlyCB->Hide();
+ m_pPrintFrameCB->Hide();
}
- if (sDlgType == "PictureDialog" || sDlgType == "ObjectDialog")
+ if (m_sDlgType == "PictureDialog" || m_sDlgType == "ObjectDialog")
{
- pEditInReadonlyCB->Hide();
- if (bHtmlMode)
+ m_pEditInReadonlyCB->Hide();
+ if (m_bHtmlMode)
{
- pPropertiesFrame->Hide();
+ m_pPropertiesFrame->Hide();
}
m_pContentAlignFrame->Hide();
}
if(SfxItemState::SET == rSet->GetItemState(FN_SET_FRM_ALT_NAME, false, &pItem))
{
- pAltNameED->SetText(static_cast<const SfxStringItem*>(pItem)->GetValue());
- pAltNameED->SaveValue();
+ m_pAltNameED->SetText(static_cast<const SfxStringItem*>(pItem)->GetValue());
+ m_pAltNameED->SaveValue();
}
- if(!bFormat)
+ if(!m_bFormat)
{
// insert graphic - properties
// bNew is not set, so recognise by selection
@@ -2968,42 +2968,42 @@ void SwFrmAddPage::Reset(const SfxItemSet *rSet )
aTmpName1 = static_cast<const SfxStringItem*>(pItem)->GetValue();
}
- OSL_ENSURE(pWrtSh, "keine Shell?");
- if( bNew || aTmpName1.isEmpty() )
+ OSL_ENSURE(m_pWrtSh, "keine Shell?");
+ if( m_bNew || aTmpName1.isEmpty() )
{
- if (sDlgType == "PictureDialog")
- aTmpName1 = pWrtSh->GetUniqueGrfName();
- else if (sDlgType == "ObjectDialog")
- aTmpName1 = pWrtSh->GetUniqueOLEName();
+ if (m_sDlgType == "PictureDialog")
+ aTmpName1 = m_pWrtSh->GetUniqueGrfName();
+ else if (m_sDlgType == "ObjectDialog")
+ aTmpName1 = m_pWrtSh->GetUniqueOLEName();
else
- aTmpName1 = pWrtSh->GetUniqueFrameName();
+ aTmpName1 = m_pWrtSh->GetUniqueFrameName();
- pWrtSh->SetFlyName(aTmpName1);
+ m_pWrtSh->SetFlyName(aTmpName1);
}
- pNameED->SetText( aTmpName1 );
- pNameED->SaveValue();
+ m_pNameED->SetText( aTmpName1 );
+ m_pNameED->SaveValue();
}
else
{
- pNameED->Enable( false );
- pAltNameED->Enable(false);
- pNameFT->Enable( false );
- pAltNameFT->Enable(false);
+ m_pNameED->Enable( false );
+ m_pAltNameED->Enable(false);
+ m_pNameFT->Enable( false );
+ m_pAltNameFT->Enable(false);
}
- if (sDlgType == "FrameDialog" && pAltNameFT->IsVisible())
+ if (m_sDlgType == "FrameDialog" && m_pAltNameFT->IsVisible())
{
- pAltNameFT->Hide();
- pAltNameED->Hide();
+ m_pAltNameFT->Hide();
+ m_pAltNameED->Hide();
}
else
{
- pNameED->SetModifyHdl(LINK(this, SwFrmAddPage, EditModifyHdl));
+ m_pNameED->SetModifyHdl(LINK(this, SwFrmAddPage, EditModifyHdl));
}
- if (!bNew)
+ if (!m_bNew)
{
- SwFrameFormat* pFormat = pWrtSh->GetFlyFrameFormat();
+ SwFrameFormat* pFormat = m_pWrtSh->GetFlyFrameFormat();
if (pFormat)
{
@@ -3024,79 +3024,79 @@ void SwFrmAddPage::Reset(const SfxItemSet *rSet )
::std::vector< OUString > aThisPageFrames;
::std::vector< OUString > aNextPageFrames;
::std::vector< OUString > aRemainFrames;
- pWrtSh->GetConnectableFrameFormats(*pFormat, sNextChain, false,
+ m_pWrtSh->GetConnectableFrameFormats(*pFormat, sNextChain, false,
aPrevPageFrames, aThisPageFrames, aNextPageFrames, aRemainFrames );
- lcl_InsertVectors(*pPrevLB, aPrevPageFrames, aThisPageFrames, aNextPageFrames, aRemainFrames);
+ lcl_InsertVectors(*m_pPrevLB, aPrevPageFrames, aThisPageFrames, aNextPageFrames, aRemainFrames);
if(!sPrevChain.isEmpty())
{
- if(LISTBOX_ENTRY_NOTFOUND == pPrevLB->GetEntryPos(sPrevChain))
- pPrevLB->InsertEntry(sPrevChain, 1);
- pPrevLB->SelectEntry(sPrevChain);
+ if(LISTBOX_ENTRY_NOTFOUND == m_pPrevLB->GetEntryPos(sPrevChain))
+ m_pPrevLB->InsertEntry(sPrevChain, 1);
+ m_pPrevLB->SelectEntry(sPrevChain);
}
else
- pPrevLB->SelectEntryPos(0);
+ m_pPrevLB->SelectEntryPos(0);
aPrevPageFrames.erase(aPrevPageFrames.begin(), aPrevPageFrames.end());
aNextPageFrames.erase(aNextPageFrames.begin(), aNextPageFrames.end());
aThisPageFrames.erase(aThisPageFrames.begin(), aThisPageFrames.end());
aRemainFrames.erase(aRemainFrames.begin(), aRemainFrames.end());
- pWrtSh->GetConnectableFrameFormats(*pFormat, sPrevChain, true,
+ m_pWrtSh->GetConnectableFrameFormats(*pFormat, sPrevChain, true,
aPrevPageFrames, aThisPageFrames, aNextPageFrames, aRemainFrames );
- lcl_InsertVectors(*pNextLB, aPrevPageFrames, aThisPageFrames, aNextPageFrames, aRemainFrames);
+ lcl_InsertVectors(*m_pNextLB, aPrevPageFrames, aThisPageFrames, aNextPageFrames, aRemainFrames);
if(!sNextChain.isEmpty())
{
- if(LISTBOX_ENTRY_NOTFOUND == pNextLB->GetEntryPos(sNextChain))
- pNextLB->InsertEntry(sNextChain, 1);
- pNextLB->SelectEntry(sNextChain);
+ if(LISTBOX_ENTRY_NOTFOUND == m_pNextLB->GetEntryPos(sNextChain))
+ m_pNextLB->InsertEntry(sNextChain, 1);
+ m_pNextLB->SelectEntry(sNextChain);
}
else
- pNextLB->SelectEntryPos(0);
+ m_pNextLB->SelectEntryPos(0);
Link<ListBox&,void> aLink(LINK(this, SwFrmAddPage, ChainModifyHdl));
- pPrevLB->SetSelectHdl(aLink);
- pNextLB->SetSelectHdl(aLink);
+ m_pPrevLB->SetSelectHdl(aLink);
+ m_pNextLB->SetSelectHdl(aLink);
}
}
// Pos Protected
const SvxProtectItem& rProt = static_cast<const SvxProtectItem& >(rSet->Get(RES_PROTECT));
- pProtectFrameCB->Check(rProt.IsPosProtected());
- pProtectContentCB->Check(rProt.IsContentProtected());
- pProtectSizeCB->Check(rProt.IsSizeProtected());
+ m_pProtectFrameCB->Check(rProt.IsPosProtected());
+ m_pProtectContentCB->Check(rProt.IsContentProtected());
+ m_pProtectSizeCB->Check(rProt.IsSizeProtected());
const SwFormatEditInReadonly& rEdit = static_cast<const SwFormatEditInReadonly& >(rSet->Get(RES_EDIT_IN_READONLY));
- pEditInReadonlyCB->Check(rEdit.GetValue()); pEditInReadonlyCB->SaveValue();
+ m_pEditInReadonlyCB->Check(rEdit.GetValue()); m_pEditInReadonlyCB->SaveValue();
// print
const SvxPrintItem& rPrt = static_cast<const SvxPrintItem&>(rSet->Get(RES_PRINT));
- pPrintFrameCB->Check(rPrt.GetValue()); pPrintFrameCB->SaveValue();
+ m_pPrintFrameCB->Check(rPrt.GetValue()); m_pPrintFrameCB->SaveValue();
// textflow
SfxItemState eState;
- if( (!bHtmlMode || (0 != (nHtmlMode&HTMLMODE_SOME_STYLES)))
- && sDlgType != "PictureDialog" && sDlgType != "ObjectDialog" &&
+ if( (!m_bHtmlMode || (0 != (nHtmlMode&HTMLMODE_SOME_STYLES)))
+ && m_sDlgType != "PictureDialog" && m_sDlgType != "ObjectDialog" &&
SfxItemState::UNKNOWN != ( eState = rSet->GetItemState(
RES_FRAMEDIR )) )
{
- pTextFlowFT->Show();
- pTextFlowLB->Show();
+ m_pTextFlowFT->Show();
+ m_pTextFlowLB->Show();
//vertical text flow is not possible in HTML
- if(bHtmlMode)
+ if(m_bHtmlMode)
{
sal_uLong nData = FRMDIR_VERT_TOP_RIGHT;
- pTextFlowLB->RemoveEntry(pTextFlowLB->GetEntryPos(reinterpret_cast<void*>(nData)));
+ m_pTextFlowLB->RemoveEntry(m_pTextFlowLB->GetEntryPos(reinterpret_cast<void*>(nData)));
}
sal_uInt16 nVal = static_cast<const SvxFrameDirectionItem&>(rSet->Get(RES_FRAMEDIR)).GetValue();
sal_Int32 nPos;
- for( nPos = pTextFlowLB->GetEntryCount(); nPos; )
- if( (sal_uInt16)reinterpret_cast<sal_IntPtr>(pTextFlowLB->GetEntryData( --nPos )) == nVal )
+ for( nPos = m_pTextFlowLB->GetEntryCount(); nPos; )
+ if( (sal_uInt16)reinterpret_cast<sal_IntPtr>(m_pTextFlowLB->GetEntryData( --nPos )) == nVal )
break;
- pTextFlowLB->SelectEntryPos( nPos );
- pTextFlowLB->SaveValue();
+ m_pTextFlowLB->SelectEntryPos( nPos );
+ m_pTextFlowLB->SaveValue();
}
else
{
- pTextFlowFT->Hide();
- pTextFlowLB->Hide();
+ m_pTextFlowFT->Hide();
+ m_pTextFlowLB->Hide();
}
// Content alignment
@@ -3119,47 +3119,47 @@ void SwFrmAddPage::Reset(const SfxItemSet *rSet )
bool SwFrmAddPage::FillItemSet(SfxItemSet *rSet)
{
bool bRet = false;
- if (pNameED->IsValueChangedFromSaved())
- bRet |= nullptr != rSet->Put(SfxStringItem(FN_SET_FRM_NAME, pNameED->GetText()));
- if (pAltNameED->IsValueChangedFromSaved())
- bRet |= nullptr != rSet->Put(SfxStringItem(FN_SET_FRM_ALT_NAME, pAltNameED->GetText()));
+ if (m_pNameED->IsValueChangedFromSaved())
+ bRet |= nullptr != rSet->Put(SfxStringItem(FN_SET_FRM_NAME, m_pNameED->GetText()));
+ if (m_pAltNameED->IsValueChangedFromSaved())
+ bRet |= nullptr != rSet->Put(SfxStringItem(FN_SET_FRM_ALT_NAME, m_pAltNameED->GetText()));
const SfxPoolItem* pOldItem;
SvxProtectItem aProt ( static_cast<const SvxProtectItem& >(GetItemSet().Get(RES_PROTECT)) );
- aProt.SetContentProtect( pProtectContentCB->IsChecked() );
- aProt.SetSizeProtect ( pProtectSizeCB->IsChecked() );
- aProt.SetPosProtect ( pProtectFrameCB->IsChecked() );
+ aProt.SetContentProtect( m_pProtectContentCB->IsChecked() );
+ aProt.SetSizeProtect ( m_pProtectSizeCB->IsChecked() );
+ aProt.SetPosProtect ( m_pProtectFrameCB->IsChecked() );
if ( nullptr == (pOldItem = GetOldItem(*rSet, FN_SET_PROTECT)) ||
aProt != *pOldItem )
bRet |= nullptr != rSet->Put( aProt);
- if ( pEditInReadonlyCB->IsValueChangedFromSaved() )
- bRet |= nullptr != rSet->Put( SwFormatEditInReadonly( RES_EDIT_IN_READONLY, pEditInReadonlyCB->IsChecked()));
+ if ( m_pEditInReadonlyCB->IsValueChangedFromSaved() )
+ bRet |= nullptr != rSet->Put( SwFormatEditInReadonly( RES_EDIT_IN_READONLY, m_pEditInReadonlyCB->IsChecked()));
- if ( pPrintFrameCB->IsValueChangedFromSaved() )
- bRet |= nullptr != rSet->Put( SvxPrintItem( RES_PRINT, pPrintFrameCB->IsChecked()));
+ if ( m_pPrintFrameCB->IsValueChangedFromSaved() )
+ bRet |= nullptr != rSet->Put( SvxPrintItem( RES_PRINT, m_pPrintFrameCB->IsChecked()));
// textflow
- if( pTextFlowLB->IsVisible() )
+ if( m_pTextFlowLB->IsVisible() )
{
- sal_Int32 nPos = pTextFlowLB->GetSelectEntryPos();
- if( pTextFlowLB->IsValueChangedFromSaved() )
+ sal_Int32 nPos = m_pTextFlowLB->GetSelectEntryPos();
+ if( m_pTextFlowLB->IsValueChangedFromSaved() )
{
- sal_uInt16 nData = (sal_uInt16)reinterpret_cast<sal_IntPtr>(pTextFlowLB->GetEntryData( nPos ));
+ sal_uInt16 nData = (sal_uInt16)reinterpret_cast<sal_IntPtr>(m_pTextFlowLB->GetEntryData( nPos ));
bRet |= nullptr != rSet->Put( SvxFrameDirectionItem(
(SvxFrameDirection)nData, RES_FRAMEDIR ));
}
}
- if(pWrtSh)
+ if(m_pWrtSh)
{
- const SwFrameFormat* pFormat = pWrtSh->GetFlyFrameFormat();
+ const SwFrameFormat* pFormat = m_pWrtSh->GetFlyFrameFormat();
if (pFormat)
{
OUString sCurrentPrevChain, sCurrentNextChain;
- if(pPrevLB->GetSelectEntryPos())
- sCurrentPrevChain = pPrevLB->GetSelectEntry();
- if(pNextLB->GetSelectEntryPos())
- sCurrentNextChain = pNextLB->GetSelectEntry();
+ if(m_pPrevLB->GetSelectEntryPos())
+ sCurrentPrevChain = m_pPrevLB->GetSelectEntry();
+ if(m_pNextLB->GetSelectEntryPos())
+ sCurrentNextChain = m_pNextLB->GetSelectEntry();
const SwFormatChain &rChain = pFormat->GetChain();
const SwFlyFrameFormat* pFlyFormat;
OUString sNextChain, sPrevChain;
@@ -3193,32 +3193,32 @@ bool SwFrmAddPage::FillItemSet(SfxItemSet *rSet)
IMPL_LINK_NOARG_TYPED(SwFrmAddPage, EditModifyHdl, Edit&, void)
{
- bool bEnable = !pNameED->GetText().isEmpty();
- pAltNameED->Enable(bEnable);
- pAltNameFT->Enable(bEnable);
+ bool bEnable = !m_pNameED->GetText().isEmpty();
+ m_pAltNameED->Enable(bEnable);
+ m_pAltNameFT->Enable(bEnable);
}
void SwFrmAddPage::SetFormatUsed(bool bFormatUsed)
{
- bFormat = bFormatUsed;
- if (bFormat)
+ m_bFormat = bFormatUsed;
+ if (m_bFormat)
{
- pNameFrame->Hide();
+ m_pNameFrame->Hide();
}
}
IMPL_LINK_TYPED(SwFrmAddPage, ChainModifyHdl, ListBox&, rBox, void)
{
OUString sCurrentPrevChain, sCurrentNextChain;
- if(pPrevLB->GetSelectEntryPos())
- sCurrentPrevChain = pPrevLB->GetSelectEntry();
- if(pNextLB->GetSelectEntryPos())
- sCurrentNextChain = pNextLB->GetSelectEntry();
- SwFrameFormat* pFormat = pWrtSh->GetFlyFrameFormat();
+ if(m_pPrevLB->GetSelectEntryPos())
+ sCurrentPrevChain = m_pPrevLB->GetSelectEntry();
+ if(m_pNextLB->GetSelectEntryPos())
+ sCurrentNextChain = m_pNextLB->GetSelectEntry();
+ SwFrameFormat* pFormat = m_pWrtSh->GetFlyFrameFormat();
if (pFormat)
{
- bool bNextBox = pNextLB == &rBox;
- ListBox& rChangeLB = bNextBox ? *pPrevLB : *pNextLB;
+ bool bNextBox = m_pNextLB == &rBox;
+ ListBox& rChangeLB = bNextBox ? *m_pPrevLB : *m_pNextLB;
for(sal_Int32 nEntry = rChangeLB.GetEntryCount(); nEntry > 1; nEntry--)
rChangeLB.RemoveEntry(nEntry - 1);
//determine chainable frames
@@ -3226,7 +3226,7 @@ IMPL_LINK_TYPED(SwFrmAddPage, ChainModifyHdl, ListBox&, rBox, void)
::std::vector< OUString > aThisPageFrames;
::std::vector< OUString > aNextPageFrames;
::std::vector< OUString > aRemainFrames;
- pWrtSh->GetConnectableFrameFormats(*pFormat, bNextBox ? sCurrentNextChain : sCurrentPrevChain, !bNextBox,
+ m_pWrtSh->GetConnectableFrameFormats(*pFormat, bNextBox ? sCurrentNextChain : sCurrentPrevChain, !bNextBox,
aPrevPageFrames, aThisPageFrames, aNextPageFrames, aRemainFrames );
lcl_InsertVectors(rChangeLB,
aPrevPageFrames, aThisPageFrames, aNextPageFrames, aRemainFrames);
diff --git a/sw/source/uibase/inc/frmpage.hxx b/sw/source/uibase/inc/frmpage.hxx
index 2f093af..a90580c 100644
--- a/sw/source/uibase/inc/frmpage.hxx
+++ b/sw/source/uibase/inc/frmpage.hxx
@@ -273,36 +273,36 @@ public:
class SwFrmAddPage : public SfxTabPage
{
- VclPtr<VclContainer> pNameFrame;
- VclPtr<FixedText> pNameFT;
- VclPtr<Edit> pNameED;
- VclPtr<FixedText> pAltNameFT;
- VclPtr<Edit> pAltNameED;
- VclPtr<FixedText> pPrevFT;
- VclPtr<ListBox> pPrevLB;
- VclPtr<FixedText> pNextFT;
- VclPtr<ListBox> pNextLB;
-
- VclPtr<VclContainer> pProtectFrame;
- VclPtr<CheckBox> pProtectContentCB;
- VclPtr<CheckBox> pProtectFrameCB;
- VclPtr<CheckBox> pProtectSizeCB;
+ VclPtr<VclContainer> m_pNameFrame;
+ VclPtr<FixedText> m_pNameFT;
+ VclPtr<Edit> m_pNameED;
+ VclPtr<FixedText> m_pAltNameFT;
+ VclPtr<Edit> m_pAltNameED;
+ VclPtr<FixedText> m_pPrevFT;
+ VclPtr<ListBox> m_pPrevLB;
+ VclPtr<FixedText> m_pNextFT;
+ VclPtr<ListBox> m_pNextLB;
+
+ VclPtr<VclContainer> m_pProtectFrame;
+ VclPtr<CheckBox> m_pProtectContentCB;
+ VclPtr<CheckBox> m_pProtectFrameCB;
+ VclPtr<CheckBox> m_pProtectSizeCB;
VclPtr<VclContainer> m_pContentAlignFrame;
VclPtr<ListBox> m_pVertAlignLB;
- VclPtr<VclContainer> pPropertiesFrame;
- VclPtr<CheckBox> pEditInReadonlyCB;
- VclPtr<CheckBox> pPrintFrameCB;
- VclPtr<FixedText> pTextFlowFT;
- VclPtr<ListBox> pTextFlowLB;
+ VclPtr<VclContainer> m_pPropertiesFrame;
+ VclPtr<CheckBox> m_pEditInReadonlyCB;
+ VclPtr<CheckBox> m_pPrintFrameCB;
+ VclPtr<FixedText> m_pTextFlowFT;
+ VclPtr<ListBox> m_pTextFlowLB;
- SwWrtShell* pWrtSh;
+ SwWrtShell* m_pWrtSh;
- OUString sDlgType;
- bool bHtmlMode;
- bool bFormat;
- bool bNew;
+ OUString m_sDlgType;
+ bool m_bHtmlMode;
+ bool m_bFormat;
+ bool m_bNew;
DECL_LINK_TYPED(EditModifyHdl, Edit&, void);
DECL_LINK_TYPED(ChainModifyHdl, ListBox&, void);
@@ -321,9 +321,9 @@ public:
virtual void Reset(const SfxItemSet *rSet) override;
void SetFormatUsed(bool bFormat);
- void SetFrmType(const OUString &rType) { sDlgType = rType; }
- void SetNewFrame(bool bNewFrame) { bNew = bNewFrame; }
- void SetShell(SwWrtShell* pSh) { pWrtSh = pSh; }
+ void SetFrmType(const OUString &rType) { m_sDlgType = rType; }
+ void SetNewFrame(bool bNewFrame) { m_bNew = bNewFrame; }
+ void SetShell(SwWrtShell* pSh) { m_pWrtSh = pSh; }
};
commit cd43da04094dad5aa545fef7ac1e13d1096a23ce
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date: Wed Nov 11 08:55:28 2015 +0100
sw: prefix members of SwWW8StyInf
Change-Id: I2749607eb2271a838acb8220c80d9363d8e8d867
diff --git a/sw/source/filter/ww8/ww8graf.cxx b/sw/source/filter/ww8/ww8graf.cxx
index 1d3113c..e937f31 100644
--- a/sw/source/filter/ww8/ww8graf.cxx
+++ b/sw/source/filter/ww8/ww8graf.cxx
@@ -478,14 +478,14 @@ ESelection GetESelection(EditEngine &rDrawEditEngine, long nCpStart, long nCpEnd
void SwWW8ImplReader::InsertTxbxStyAttrs( SfxItemSet& rS, sal_uInt16 nColl )
{
SwWW8StyInf * pStyInf = GetStyle(nColl);
- if( pStyInf != nullptr && pStyInf->pFormat && pStyInf->bColl )
+ if( pStyInf != nullptr && pStyInf->m_pFormat && pStyInf->m_bColl )
{
const SfxPoolItem* pItem;
for( sal_uInt16 i = POOLATTR_BEGIN; i < POOLATTR_END; i++ )
{
// If we are set in the source and not set in the destination
// then add it in.
- if ( SfxItemState::SET == pStyInf->pFormat->GetItemState(
+ if ( SfxItemState::SET == pStyInf->m_pFormat->GetItemState(
i, true, &pItem ) )
{
SfxItemPool *pEditPool = rS.GetPool();
diff --git a/sw/source/filter/ww8/ww8par.cxx b/sw/source/filter/ww8/ww8par.cxx
index 1bf4914..124cd50 100644
--- a/sw/source/filter/ww8/ww8par.cxx
+++ b/sw/source/filter/ww8/ww8par.cxx
@@ -1721,15 +1721,15 @@ void SwWW8ImplReader::Read_Tab(sal_uInt16 , const sal_uInt8* pData, short nLen)
sal_uInt16 nTabBase;
if (m_pAktColl && m_nAktColl < m_vColl.size()) // StyleDef
{
- nTabBase = m_vColl[m_nAktColl].nBase;
+ nTabBase = m_vColl[m_nAktColl].m_nBase;
if (nTabBase < m_vColl.size()) // Based On
- pSty = static_cast<const SwTextFormatColl*>(m_vColl[nTabBase].pFormat);
+ pSty = static_cast<const SwTextFormatColl*>(m_vColl[nTabBase].m_pFormat);
}
else
{ // Text
nTabBase = m_nAktColl;
if (m_nAktColl < m_vColl.size())
- pSty = static_cast<const SwTextFormatColl*>(m_vColl[m_nAktColl].pFormat);
+ pSty = static_cast<const SwTextFormatColl*>(m_vColl[m_nAktColl].m_pFormat);
//TODO: figure out else here
}
@@ -1747,7 +1747,7 @@ void SwWW8ImplReader::Read_Tab(sal_uInt16 , const sal_uInt8* pData, short nLen)
sal_uInt16 nOldTabBase = nTabBase;
// If based on another
if (nTabBase < m_vColl.size())
- nTabBase = m_vColl[nTabBase].nBase;
+ nTabBase = m_vColl[nTabBase].m_nBase;
if (
nTabBase < m_vColl.size() &&
@@ -1759,7 +1759,7 @@ void SwWW8ImplReader::Read_Tab(sal_uInt16 , const sal_uInt8* pData, short nLen)
// current one (prevent loop)
aLoopWatch.insert(reinterpret_cast<size_t>(pSty));
if (nTabBase < m_vColl.size())
- pSty = static_cast<const SwTextFormatColl*>(m_vColl[nTabBase].pFormat);
+ pSty = static_cast<const SwTextFormatColl*>(m_vColl[nTabBase].m_pFormat);
//TODO figure out the else branch
if (aLoopWatch.find(reinterpret_cast<size_t>(pSty)) !=
@@ -3708,7 +3708,7 @@ void SwWW8ImplReader::ProcessAktCollChange(WW8PLCFManResult& rRes,
m_nAktColl = m_pPlcxMan->GetColl();
// Invalid Style-Id
- if (m_nAktColl >= m_vColl.size() || !m_vColl[m_nAktColl].pFormat || !m_vColl[m_nAktColl].bColl)
+ if (m_nAktColl >= m_vColl.size() || !m_vColl[m_nAktColl].m_pFormat || !m_vColl[m_nAktColl].m_bColl)
{
m_nAktColl = 0;
m_bParaAutoBefore = false;
@@ -3716,8 +3716,8 @@ void SwWW8ImplReader::ProcessAktCollChange(WW8PLCFManResult& rRes,
}
else
{
- m_bParaAutoBefore = m_vColl[m_nAktColl].bParaAutoBefore;
- m_bParaAutoAfter = m_vColl[m_nAktColl].bParaAutoAfter;
+ m_bParaAutoBefore = m_vColl[m_nAktColl].m_bParaAutoBefore;
+ m_bParaAutoAfter = m_vColl[m_nAktColl].m_bParaAutoAfter;
}
if (nOldColl >= m_vColl.size())
@@ -3736,9 +3736,9 @@ void SwWW8ImplReader::ProcessAktCollChange(WW8PLCFManResult& rRes,
if (!bTabRowEnd && StyleExists(m_nAktColl))
{
SetTextFormatCollAndListLevel( *m_pPaM, m_vColl[ m_nAktColl ]);
- ChkToggleAttr(m_vColl[ nOldColl ].n81Flags, m_vColl[ m_nAktColl ].n81Flags);
- ChkToggleBiDiAttr(m_vColl[nOldColl].n81BiDiFlags,
- m_vColl[m_nAktColl].n81BiDiFlags);
+ ChkToggleAttr(m_vColl[ nOldColl ].m_n81Flags, m_vColl[ m_nAktColl ].m_n81Flags);
+ ChkToggleBiDiAttr(m_vColl[nOldColl].m_n81BiDiFlags,
+ m_vColl[m_nAktColl].m_n81BiDiFlags);
}
}
@@ -5882,7 +5882,7 @@ void SwWW8ImplReader::SetOutlineStyles()
{
SwWW8StyInf* pStyleInf = (*aStyleIter);
- if (!pStyleInf->bColl) //Character Style
+ if (!pStyleInf->m_bColl) //Character Style
continue;
const sal_uInt16 nOutlineStyleListLevelOfWW8BuiltInHeadingStyle
@@ -5894,7 +5894,7 @@ void SwWW8ImplReader::SetOutlineStyles()
}
if (pChosenWW8ListStyle != nullptr && pStyleInf->mnWW8OutlineLevel
- == pStyleInf->nListLevel)
+ == pStyleInf->m_nListLevel)
{
const SwNumFormat& rRule
= pChosenWW8ListStyle->Get(pStyleInf->mnWW8OutlineLevel);
@@ -5906,10 +5906,10 @@ void SwWW8ImplReader::SetOutlineStyles()
nOutlineStyleListLevelWithAssignment
|= nOutlineStyleListLevelOfWW8BuiltInHeadingStyle;
- SwTextFormatColl* pTextFormatColl = static_cast<SwTextFormatColl*>(pStyleInf->pFormat);
+ SwTextFormatColl* pTextFormatColl = static_cast<SwTextFormatColl*>(pStyleInf->m_pFormat);
if (pStyleInf->GetOutlineNumrule() != pChosenWW8ListStyle
- || (pStyleInf->nListLevel < WW8ListManager::nMaxLevel
- && pStyleInf->mnWW8OutlineLevel != pStyleInf->nListLevel))
+ || (pStyleInf->m_nListLevel < WW8ListManager::nMaxLevel
+ && pStyleInf->mnWW8OutlineLevel != pStyleInf->m_nListLevel))
{
// WW8 Built-In Heading Style does not apply the chosen one.
// --> delete assignment to OutlineStyle, but keep its current
diff --git a/sw/source/filter/ww8/ww8par.hxx b/sw/source/filter/ww8/ww8par.hxx
index e0b0eab..ab3bd02 100644
--- a/sw/source/filter/ww8/ww8par.hxx
+++ b/sw/source/filter/ww8/ww8par.hxx
@@ -215,20 +215,20 @@ struct WW8FlyPara
class SwWW8StyInf
{
- OUString sWWStyleName;
- sal_uInt16 nWWStyleId;
+ OUString m_sWWStyleName;
+ sal_uInt16 m_nWWStyleId;
public:
- rtl_TextEncoding eLTRFontSrcCharSet; // rtl_TextEncoding for the font
- rtl_TextEncoding eRTLFontSrcCharSet; // rtl_TextEncoding for the font
- rtl_TextEncoding eCJKFontSrcCharSet; // rtl_TextEncoding for the font
- SwFormat* pFormat;
- WW8FlyPara* pWWFly;
- SwNumRule* pOutlineNumrule;
- long nFilePos;
- sal_uInt16 nBase;
- sal_uInt16 nFollow;
- sal_uInt16 nLFOIndex;
- sal_uInt8 nListLevel;
+ rtl_TextEncoding m_eLTRFontSrcCharSet; // rtl_TextEncoding for the font
+ rtl_TextEncoding m_eRTLFontSrcCharSet; // rtl_TextEncoding for the font
+ rtl_TextEncoding m_eCJKFontSrcCharSet; // rtl_TextEncoding for the font
+ SwFormat* m_pFormat;
+ WW8FlyPara* m_pWWFly;
+ SwNumRule* m_pOutlineNumrule;
+ long m_nFilePos;
+ sal_uInt16 m_nBase;
+ sal_uInt16 m_nFollow;
+ sal_uInt16 m_nLFOIndex;
+ sal_uInt8 m_nListLevel;
// WW8 outline level is zero-based:
// 0: outline level 1
@@ -238,95 +238,95 @@ public:
// 9: body text
sal_uInt8 mnWW8OutlineLevel;
- sal_uInt16 n81Flags; // for bold, italic, ...
- sal_uInt16 n81BiDiFlags; // for bold, italic, ...
+ sal_uInt16 m_n81Flags; // for bold, italic, ...
+ sal_uInt16 m_n81BiDiFlags; // for bold, italic, ...
SvxLRSpaceItem maWordLR;
- bool bValid; // empty of valid
- bool bImported; // for recursive imports
- bool bColl; // true-> pFormat is SwTextFormatColl
- bool bImportSkipped; // only true if !bNewDoc && existing style
- bool bHasStyNumRule; // true-> named NumRule in style
- bool bHasBrokenWW6List; // true-> WW8+ style has a WW7- list
- bool bListReleventIndentSet; //true if this style's indent has
+ bool m_bValid; // empty of valid
+ bool m_bImported; // for recursive imports
+ bool m_bColl; // true-> pFormat is SwTextFormatColl
+ bool m_bImportSkipped; // only true if !bNewDoc && existing style
+ bool m_bHasStyNumRule; // true-> named NumRule in style
+ bool m_bHasBrokenWW6List; // true-> WW8+ style has a WW7- list
+ bool m_bListReleventIndentSet; //true if this style's indent has
//been explicitly set, it's set to the value
//of pFormat->GetItemState(RES_LR_SPACE, false)
//if it was possible to get the ItemState
//for L of the LR space independently
- bool bParaAutoBefore; // For Auto spacing before a paragraph
- bool bParaAutoAfter; // For Auto Spacing after a paragraph
+ bool m_bParaAutoBefore; // For Auto spacing before a paragraph
+ bool m_bParaAutoAfter; // For Auto Spacing after a paragraph
SwWW8StyInf() :
- sWWStyleName( OUString() ),
- nWWStyleId( 0 ),
- eLTRFontSrcCharSet(0),
- eRTLFontSrcCharSet(0),
- eCJKFontSrcCharSet(0),
- pFormat( nullptr ),
- pWWFly( nullptr ),
- pOutlineNumrule( nullptr ),
- nFilePos( 0 ),
- nBase( 0 ),
- nFollow( 0 ),
- nLFOIndex( USHRT_MAX ),
- nListLevel(WW8ListManager::nMaxLevel),
+ m_sWWStyleName( OUString() ),
+ m_nWWStyleId( 0 ),
+ m_eLTRFontSrcCharSet(0),
+ m_eRTLFontSrcCharSet(0),
+ m_eCJKFontSrcCharSet(0),
+ m_pFormat( nullptr ),
+ m_pWWFly( nullptr ),
+ m_pOutlineNumrule( nullptr ),
+ m_nFilePos( 0 ),
+ m_nBase( 0 ),
+ m_nFollow( 0 ),
+ m_nLFOIndex( USHRT_MAX ),
+ m_nListLevel(WW8ListManager::nMaxLevel),
mnWW8OutlineLevel( MAXLEVEL ),
- n81Flags( 0 ),
- n81BiDiFlags(0),
+ m_n81Flags( 0 ),
+ m_n81BiDiFlags(0),
maWordLR( RES_LR_SPACE ),
- bValid(false),
- bImported(false),
- bColl(false),
- bImportSkipped(false),
- bHasStyNumRule(false),
- bHasBrokenWW6List(false),
- bListReleventIndentSet(false),
- bParaAutoBefore(false),
- bParaAutoAfter(false)
+ m_bValid(false),
+ m_bImported(false),
+ m_bColl(false),
+ m_bImportSkipped(false),
+ m_bHasStyNumRule(false),
+ m_bHasBrokenWW6List(false),
+ m_bListReleventIndentSet(false),
+ m_bParaAutoBefore(false),
+ m_bParaAutoAfter(false)
{}
~SwWW8StyInf()
{
- delete pWWFly;
+ delete m_pWWFly;
}
void SetOrgWWIdent( const OUString& rName, const sal_uInt16 nId )
{
- sWWStyleName = rName;
- nWWStyleId = nId;
+ m_sWWStyleName = rName;
+ m_nWWStyleId = nId;
// apply default WW8 outline level to WW8 Built-in Heading styles
if (IsWW8BuiltInHeadingStyle())
{
- mnWW8OutlineLevel = nWWStyleId - 1;
+ mnWW8OutlineLevel = m_nWWStyleId - 1;
}
}
const OUString& GetOrgWWName() const
{
- return sWWStyleName;
+ return m_sWWStyleName;
}
bool HasWW8OutlineLevel() const
{
- return (pFormat != nullptr && (MAXLEVEL > mnWW8OutlineLevel));
+ return (m_pFormat != nullptr && (MAXLEVEL > mnWW8OutlineLevel));
}
bool IsOutlineNumbered() const
{
- return pOutlineNumrule && HasWW8OutlineLevel();
+ return m_pOutlineNumrule && HasWW8OutlineLevel();
}
const SwNumRule* GetOutlineNumrule() const
{
- return pOutlineNumrule;
+ return m_pOutlineNumrule;
}
rtl_TextEncoding GetCharSet() const;
rtl_TextEncoding GetCJKCharSet() const;
sal_uInt16 GetWWStyleId() const
{
- return nWWStyleId;
+ return m_nWWStyleId;
}
bool IsWW8BuiltInHeadingStyle() const
diff --git a/sw/source/filter/ww8/ww8par3.cxx b/sw/source/filter/ww8/ww8par3.cxx
index 6d7750b..b08071a 100644
--- a/sw/source/filter/ww8/ww8par3.cxx
+++ b/sw/source/filter/ww8/ww8par3.cxx
@@ -1675,9 +1675,9 @@ bool SwWW8ImplReader::SetTextFormatCollAndListLevel(const SwPaM& rRg,
SwWW8StyInf& rStyleInfo)
{
bool bRes = true;
- if( rStyleInfo.pFormat && rStyleInfo.bColl )
+ if( rStyleInfo.m_pFormat && rStyleInfo.m_bColl )
{
- bRes = m_rDoc.SetTextFormatColl(rRg, static_cast<SwTextFormatColl*>(rStyleInfo.pFormat));
+ bRes = m_rDoc.SetTextFormatColl(rRg, static_cast<SwTextFormatColl*>(rStyleInfo.m_pFormat));
SwTextNode* pTextNode = m_pPaM->GetNode().GetTextNode();
OSL_ENSURE( pTextNode, "No Text-Node at PaM-Position" );
if ( !pTextNode )
@@ -1694,11 +1694,11 @@ bool SwWW8ImplReader::SetTextFormatCollAndListLevel(const SwPaM& rRg,
pTextNode->ResetAttr( RES_PARATR_NUMRULE );
}
- if (USHRT_MAX > rStyleInfo.nLFOIndex && WW8ListManager::nMaxLevel
- > rStyleInfo.nListLevel)
+ if (USHRT_MAX > rStyleInfo.m_nLFOIndex && WW8ListManager::nMaxLevel
+ > rStyleInfo.m_nListLevel)
{
const bool bApplyListStyle = false;
- RegisterNumFormatOnTextNode(rStyleInfo.nLFOIndex, rStyleInfo.nListLevel,
+ RegisterNumFormatOnTextNode(rStyleInfo.m_nLFOIndex, rStyleInfo.m_nListLevel,
bApplyListStyle);
}
}
@@ -1712,11 +1712,11 @@ void UseListIndent(SwWW8StyInf &rStyle, const SwNumFormat &rFormat)
{
const long nAbsLSpace = rFormat.GetAbsLSpace();
const long nListFirstLineIndent = GetListFirstLineIndent(rFormat);
- SvxLRSpaceItem aLR(ItemGet<SvxLRSpaceItem>(*rStyle.pFormat, RES_LR_SPACE));
+ SvxLRSpaceItem aLR(ItemGet<SvxLRSpaceItem>(*rStyle.m_pFormat, RES_LR_SPACE));
aLR.SetTextLeft(nAbsLSpace);
aLR.SetTextFirstLineOfst(writer_cast<short>(nListFirstLineIndent));
- rStyle.pFormat->SetFormatAttr(aLR);
- rStyle.bListReleventIndentSet = true;
+ rStyle.m_pFormat->SetFormatAttr(aLR);
+ rStyle.m_bListReleventIndentSet = true;
}
}
@@ -1724,8 +1724,8 @@ void SetStyleIndent(SwWW8StyInf &rStyle, const SwNumFormat &rFormat)
{
if ( rFormat.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_WIDTH_AND_POSITION ) // #i86652#
{
- SvxLRSpaceItem aLR(ItemGet<SvxLRSpaceItem>(*rStyle.pFormat, RES_LR_SPACE));
- if (rStyle.bListReleventIndentSet)
+ SvxLRSpaceItem aLR(ItemGet<SvxLRSpaceItem>(*rStyle.m_pFormat, RES_LR_SPACE));
+ if (rStyle.m_bListReleventIndentSet)
{
SyncIndentWithList( aLR, rFormat, false, false ); // #i103711#, #i105414#
@@ -1735,7 +1735,7 @@ void SetStyleIndent(SwWW8StyInf &rStyle, const SwNumFormat &rFormat)
aLR.SetTextLeft(0);
aLR.SetTextFirstLineOfst(0);
}
- rStyle.pFormat->SetFormatAttr(aLR);
+ rStyle.m_pFormat->SetFormatAttr(aLR);
}
}
@@ -1746,7 +1746,7 @@ void SwWW8ImplReader::SetStylesList(sal_uInt16 nStyle, sal_uInt16 nActLFO,
return;
SwWW8StyInf &rStyleInf = m_vColl[nStyle];
- if (rStyleInf.bValid)
+ if (rStyleInf.m_bValid)
{
OSL_ENSURE(m_pAktColl, "Cannot be called outside of style import");
// Phase 1: Nummerierungsattribute beim Einlesen einer StyleDef
@@ -1759,8 +1759,8 @@ void SwWW8ImplReader::SetStylesList(sal_uInt16 nStyle, sal_uInt16 nActLFO,
(WW8ListManager::nMaxLevel > nActLevel)
)
{
- rStyleInf.nLFOIndex = nActLFO;
- rStyleInf.nListLevel = nActLevel;
+ rStyleInf.m_nLFOIndex = nActLFO;
+ rStyleInf.m_nListLevel = nActLevel;
if (
(USHRT_MAX > nActLFO) &&
@@ -1786,16 +1786,16 @@ void SwWW8ImplReader::RegisterNumFormatOnStyle(sal_uInt16 nStyle)
return;
SwWW8StyInf &rStyleInf = m_vColl[nStyle];
- if (rStyleInf.bValid && rStyleInf.pFormat)
+ if (rStyleInf.m_bValid && rStyleInf.m_pFormat)
{
//Save old pre-list modified indent, which are the word indent values
rStyleInf.maWordLR =
- ItemGet<SvxLRSpaceItem>(*rStyleInf.pFormat, RES_LR_SPACE);
+ ItemGet<SvxLRSpaceItem>(*rStyleInf.m_pFormat, RES_LR_SPACE);
// Phase 2: aktualisieren der StyleDef nach einlesen aller Listen
SwNumRule* pNmRule = nullptr;
- const sal_uInt16 nLFO = rStyleInf.nLFOIndex;
- const sal_uInt8 nLevel = rStyleInf.nListLevel;
+ const sal_uInt16 nLFO = rStyleInf.m_nLFOIndex;
+ const sal_uInt8 nLevel = rStyleInf.m_nListLevel;
if (
(USHRT_MAX > nLFO) &&
(WW8ListManager::nMaxLevel > nLevel)
@@ -1810,13 +1810,13 @@ void SwWW8ImplReader::RegisterNumFormatOnStyle(sal_uInt16 nStyle)
if (rStyleInf.IsWW8BuiltInHeadingStyle()
&& rStyleInf.HasWW8OutlineLevel())
{
- rStyleInf.pOutlineNumrule = pNmRule;
+ rStyleInf.m_pOutlineNumrule = pNmRule;
}
else
{
- rStyleInf.pFormat->SetFormatAttr(
+ rStyleInf.m_pFormat->SetFormatAttr(
SwNumRuleItem(pNmRule->GetName()));
- rStyleInf.bHasStyNumRule = true;
+ rStyleInf.m_bHasStyNumRule = true;
}
}
}
@@ -2056,7 +2056,7 @@ void SwWW8ImplReader::Read_LFOPosition(sal_uInt16, const sal_uInt8* pData,
braindeadness
*/
if (m_pAktColl && (m_nLFOPosition == 2047-1) && m_nAktColl < m_vColl.size())
- m_vColl[m_nAktColl].bHasBrokenWW6List = true;
+ m_vColl[m_nAktColl].m_bHasBrokenWW6List = true;
// die Streamdaten sind hier 1 basiert, wir ziehen EINS ab
if (USHRT_MAX > m_nLFOPosition)
diff --git a/sw/source/filter/ww8/ww8par6.cxx b/sw/source/filter/ww8/ww8par6.cxx
index 2d88ac7..092c694 100644
--- a/sw/source/filter/ww8/ww8par6.cxx
+++ b/sw/source/filter/ww8/ww8par6.cxx
@@ -270,10 +270,10 @@ void SwWW8ImplReader::SetDocumentGrid(SwFrameFormat &rFormat, const wwSection &r
sal_uInt32 nCharWidth=240;
for (sal_uInt16 nI = 0; nI < m_pStyles->GetCount(); ++nI)
{
- if (m_vColl[nI].bValid && m_vColl[nI].pFormat &&
+ if (m_vColl[nI].m_bValid && m_vColl[nI].m_pFormat &&
m_vColl[nI].IsWW8BuiltInDefaultStyle())
{
- nCharWidth = ItemGet<SvxFontHeightItem>(*(m_vColl[nI].pFormat),
+ nCharWidth = ItemGet<SvxFontHeightItem>(*(m_vColl[nI].m_pFormat),
RES_CHRATR_CJK_FONTSIZE).GetHeight();
break;
}
@@ -1656,9 +1656,9 @@ void WW8FlyPara::ReadFull(sal_uInt8 nOrigSp29, SwWW8ImplReader* pIo)
WW8FlyPara *pNowStyleApo=nullptr;
sal_uInt16 nColl = pPap->GetIstd();
ww::sti eSti = eVer < ww::eWW6 ? ww::GetCanonicalStiFromStc( static_cast< sal_uInt8 >(nColl) ) : static_cast<ww::sti>(nColl);
- while (eSti != ww::stiNil && nColl < pIo->m_vColl.size() && nullptr == (pNowStyleApo = pIo->m_vColl[nColl].pWWFly))
+ while (eSti != ww::stiNil && nColl < pIo->m_vColl.size() && nullptr == (pNowStyleApo = pIo->m_vColl[nColl].m_pWWFly))
{
- nColl = pIo->m_vColl[nColl].nBase;
+ nColl = pIo->m_vColl[nColl].m_nBase;
eSti = eVer < ww::eWW6 ? ww::GetCanonicalStiFromStc( static_cast< sal_uInt8 >(nColl) ) : static_cast<ww::sti>(nColl);
}
@@ -2681,10 +2681,10 @@ const SfxPoolItem* SwWW8ImplReader::GetFormatAttr( sal_uInt16 nWhich )
pRet = m_pCtrlStck->GetStackAttr(*m_pPaM->GetPoint(), nWhich);
if (!pRet)
{
- if (m_nAktColl < m_vColl.size() && m_vColl[m_nAktColl].pFormat &&
- m_vColl[m_nAktColl].bColl)
+ if (m_nAktColl < m_vColl.size() && m_vColl[m_nAktColl].m_pFormat &&
+ m_vColl[m_nAktColl].m_bColl)
{
- pRet = &(m_vColl[m_nAktColl].pFormat->GetFormatAttr(nWhich));
+ pRet = &(m_vColl[m_nAktColl].m_pFormat->GetFormatAttr(nWhich));
}
}
if (!pRet)
@@ -2901,17 +2901,17 @@ void SwWW8ImplReader::Read_BoldUsw( sal_uInt16 nId, const sal_uInt8* pData, shor
{
// The style based on has Bit 7 set ?
if (
- pSI->nBase < m_vColl.size() && (*pData & 0x80) &&
- (m_vColl[pSI->nBase].n81Flags & nMask)
+ pSI->m_nBase < m_vColl.size() && (*pData & 0x80) &&
+ (m_vColl[pSI->m_nBase].m_n81Flags & nMask)
)
{
bOn = !bOn; // invert
}
if (bOn)
- pSI->n81Flags |= nMask; // set flag
+ pSI->m_n81Flags |= nMask; // set flag
else
- pSI->n81Flags &= ~nMask; // delete flag
+ pSI->m_n81Flags &= ~nMask; // delete flag
}
}
else
@@ -2920,7 +2920,7 @@ void SwWW8ImplReader::Read_BoldUsw( sal_uInt16 nId, const sal_uInt8* pData, shor
// in text -> look at flags
if( *pData & 0x80 ) // bit 7 set?
{
- if (pSI && pSI->n81Flags & nMask) // and in StyleDef at ?
+ if (pSI && pSI->m_n81Flags & nMask) // and in StyleDef at ?
bOn = !bOn; // then invert
// remember on stack that this is a toggle-attribute
m_pCtrlStck->SetToggleAttr(nI, true);
@@ -2989,15 +2989,15 @@ void SwWW8ImplReader::Read_BoldBiDiUsw(sal_uInt16 nId, const sal_uInt8* pData,
{
if (pSI)
{
- if( pSI->nBase < m_vColl.size() // Style Based on
+ if( pSI->m_nBase < m_vColl.size() // Style Based on
&& ( *pData & 0x80 ) // bit 7 set?
- && ( m_vColl[pSI->nBase].n81BiDiFlags & nMask ) ) // base mask?
+ && ( m_vColl[pSI->m_nBase].m_n81BiDiFlags & nMask ) ) // base mask?
bOn = !bOn; // invert
if( bOn )
- pSI->n81BiDiFlags |= nMask; // set flag
+ pSI->m_n81BiDiFlags |= nMask; // set flag
else
- pSI->n81BiDiFlags &= ~nMask; // delete flag
+ pSI->m_n81BiDiFlags &= ~nMask; // delete flag
}
}
else
@@ -3006,7 +3006,7 @@ void SwWW8ImplReader::Read_BoldBiDiUsw(sal_uInt16 nId, const sal_uInt8* pData,
// in text -> look at flags
if (*pData & 0x80) // Bit 7 set?
{
- if (pSI && pSI->n81BiDiFlags & nMask) // and in StyleDef at ?
+ if (pSI && pSI->m_n81BiDiFlags & nMask) // and in StyleDef at ?
bOn = !bOn; // then invert
// remember on stack that this is a toggle-attribute
m_pCtrlStck->SetToggleBiDiAttr(nI, true);
@@ -3561,13 +3561,13 @@ bool SwWW8ImplReader::SetNewFontAttr(sal_uInt16 nFCode, bool bSetEnums,
{
default:
case RES_CHRATR_FONT:
- m_vColl[m_nAktColl].eLTRFontSrcCharSet = eSrcCharSet;
+ m_vColl[m_nAktColl].m_eLTRFontSrcCharSet = eSrcCharSet;
break;
case RES_CHRATR_CTL_FONT:
- m_vColl[m_nAktColl].eRTLFontSrcCharSet = eSrcCharSet;
+ m_vColl[m_nAktColl].m_eRTLFontSrcCharSet = eSrcCharSet;
break;
case RES_CHRATR_CJK_FONT:
- m_vColl[m_nAktColl].eCJKFontSrcCharSet = eSrcCharSet;
+ m_vColl[m_nAktColl].m_eCJKFontSrcCharSet = eSrcCharSet;
break;
}
}
@@ -3793,8 +3793,8 @@ void SwWW8ImplReader::Read_CColl( sal_uInt16, const sal_uInt8* pData, short nLen
}
sal_uInt16 nId = SVBT16ToShort( pData ); // Style-Id (NOT Sprm-Id!)
- if( nId >= m_vColl.size() || !m_vColl[nId].pFormat // invalid Id?
- || m_vColl[nId].bColl ) // or paragraph style?
+ if( nId >= m_vColl.size() || !m_vColl[nId].m_pFormat // invalid Id?
+ || m_vColl[nId].m_bColl ) // or paragraph style?
return; // then ignore
// if current on loading a TOX field, and current trying to apply a hyperlink character style,
@@ -3806,7 +3806,7 @@ void SwWW8ImplReader::Read_CColl( sal_uInt16, const sal_uInt8* pData, short nLen
return;
}
- NewAttr( SwFormatCharFormat( static_cast<SwCharFormat*>(m_vColl[nId].pFormat) ) );
+ NewAttr( SwFormatCharFormat( static_cast<SwCharFormat*>(m_vColl[nId].m_pFormat) ) );
m_nCharFormat = (short) nId;
}
@@ -4004,7 +4004,7 @@ void SwWW8ImplReader::Read_LR( sal_uInt16 nId, const sal_uInt8* pData, short nLe
aLR.SetTextLeft( nPara );
if (m_pAktColl && m_nAktColl < m_vColl.size())
{
- m_vColl[m_nAktColl].bListReleventIndentSet = true;
+ m_vColl[m_nAktColl].m_bListReleventIndentSet = true;
}
bLeftIndentSet = true; // #i105414#
break;
@@ -4023,13 +4023,13 @@ void SwWW8ImplReader::Read_LR( sal_uInt16 nId, const sal_uInt8* pData, short nLe
been removed then we will factor the original list applied hanging
into our calculation.
*/
- if (m_pPlcxMan && m_nAktColl < m_vColl.size() && m_vColl[m_nAktColl].bHasBrokenWW6List)
+ if (m_pPlcxMan && m_nAktColl < m_vColl.size() && m_vColl[m_nAktColl].m_bHasBrokenWW6List)
{
const sal_uInt8 *pIsZeroed = m_pPlcxMan->GetPapPLCF()->HasSprm(0x460B);
if (pIsZeroed && *pIsZeroed == 0)
{
const SvxLRSpaceItem &rLR =
- ItemGet<SvxLRSpaceItem>(*(m_vColl[m_nAktColl].pFormat),
+ ItemGet<SvxLRSpaceItem>(*(m_vColl[m_nAktColl].m_pFormat),
RES_LR_SPACE);
nPara = nPara - rLR.GetTextFirstLineOfst();
}
@@ -4057,7 +4057,7 @@ void SwWW8ImplReader::Read_LR( sal_uInt16 nId, const sal_uInt8* pData, short nLe
}
if (m_pAktColl && m_nAktColl < m_vColl.size())
{
- m_vColl[m_nAktColl].bListReleventIndentSet = true;
+ m_vColl[m_nAktColl].m_bListReleventIndentSet = true;
}
bFirstLinOfstSet = true; // #i103711#
break;
@@ -4161,14 +4161,14 @@ void SwWW8ImplReader::Read_ParaAutoBefore(sal_uInt16, const sal_uInt8 *pData, sh
aUL.SetUpper(GetParagraphAutoSpace(m_pWDop->fDontUseHTMLAutoSpacing));
NewAttr(aUL);
if (m_pAktColl && m_nAktColl < m_vColl.size())
- m_vColl[m_nAktColl].bParaAutoBefore = true;
+ m_vColl[m_nAktColl].m_bParaAutoBefore = true;
else
m_bParaAutoBefore = true;
}
else
{
if (m_pAktColl && m_nAktColl < m_vColl.size())
- m_vColl[m_nAktColl].bParaAutoBefore = false;
+ m_vColl[m_nAktColl].m_bParaAutoBefore = false;
else
m_bParaAutoBefore = false;
}
@@ -4188,14 +4188,14 @@ void SwWW8ImplReader::Read_ParaAutoAfter(sal_uInt16, const sal_uInt8 *pData, sho
aUL.SetLower(GetParagraphAutoSpace(m_pWDop->fDontUseHTMLAutoSpacing));
NewAttr(aUL);
if (m_pAktColl && m_nAktColl < m_vColl.size())
- m_vColl[m_nAktColl].bParaAutoAfter = true;
+ m_vColl[m_nAktColl].m_bParaAutoAfter = true;
else
m_bParaAutoAfter = true;
}
else
{
if (m_pAktColl && m_nAktColl < m_vColl.size())
- m_vColl[m_nAktColl].bParaAutoAfter = false;
+ m_vColl[m_nAktColl].m_bParaAutoAfter = false;
else
m_bParaAutoAfter = false;
}
@@ -4972,11 +4972,11 @@ void SwWW8ImplReader::Read_ApoPPC( sal_uInt16, const sal_uInt8* pData, short )
if (m_pAktColl && m_nAktColl < m_vColl.size()) // only for Styledef, sonst anders geloest
{
SwWW8StyInf& rSI = m_vColl[m_nAktColl];
- WW8FlyPara* pFly = rSI.pWWFly ? rSI.pWWFly : new WW8FlyPara(m_bVer67);
- m_vColl[m_nAktColl].pWWFly = pFly;
+ WW8FlyPara* pFly = rSI.m_pWWFly ? rSI.m_pWWFly : new WW8FlyPara(m_bVer67);
+ m_vColl[m_nAktColl].m_pWWFly = pFly;
pFly->Read(*pData, m_pStyles);
if (pFly->IsEmpty())
- delete m_vColl[m_nAktColl].pWWFly, m_vColl[m_nAktColl].pWWFly = nullptr;
+ delete m_vColl[m_nAktColl].m_pWWFly, m_vColl[m_nAktColl].m_pWWFly = nullptr;
}
}
commit cd6f2ffbcea36ceee75fa377c08e0f84f9b8b793
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date: Wed Nov 11 08:54:31 2015 +0100
sw: prefix members of SwTOXDescription
Change-Id: I6189595cf20e371f29de8709abb742737bf5a770
diff --git a/sw/source/uibase/inc/toxmgr.hxx b/sw/source/uibase/inc/toxmgr.hxx
index d9c57bf..12cfb78 100644
--- a/sw/source/uibase/inc/toxmgr.hxx
+++ b/sw/source/uibase/inc/toxmgr.hxx
@@ -31,32 +31,32 @@ class SwForm;
//one single method will be sufficient to insert AND upate indexes
class SW_DLLPUBLIC SwTOXDescription
{
- TOXTypes eTOXType;
- OUString aStyleNames[MAXLEVEL];
- OUString sSequenceName;
- OUString sMainEntryCharStyle;
- OUString sAutoMarkURL;
- OUString* pTitle;
- OUString* pTOUName;
- SwForm* pForm;
- sal_uInt16 nContent;
- sal_uInt16 nIndexOptions;
- sal_uInt16 nOLEOptions;
- LanguageType eLanguage;
- OUString sSortAlgorithm;
-
- OUString sAuthBrackets;
- SwCaptionDisplay eCaptionDisplay;
- SwTOXSortKey eSortKey1;
- SwTOXSortKey eSortKey2;
- SwTOXSortKey eSortKey3;
- sal_uInt8 nLevel;
- bool bFromObjectNames : 1;
- bool bFromChapter : 1;
- bool bReadonly: 1;
- bool bLevelFromChapter : 1;
- bool bIsAuthSequence :1;
- bool bSortByDocument :1;
+ TOXTypes m_eTOXType;
+ OUString m_aStyleNames[MAXLEVEL];
+ OUString m_sSequenceName;
+ OUString m_sMainEntryCharStyle;
+ OUString m_sAutoMarkURL;
+ OUString* m_pTitle;
+ OUString* m_pTOUName;
+ SwForm* m_pForm;
+ sal_uInt16 m_nContent;
+ sal_uInt16 m_nIndexOptions;
+ sal_uInt16 m_nOLEOptions;
+ LanguageType m_eLanguage;
+ OUString m_sSortAlgorithm;
+
+ OUString m_sAuthBrackets;
+ SwCaptionDisplay m_eCaptionDisplay;
+ SwTOXSortKey m_eSortKey1;
+ SwTOXSortKey m_eSortKey2;
+ SwTOXSortKey m_eSortKey3;
+ sal_uInt8 m_nLevel;
+ bool m_bFromObjectNames : 1;
+ bool m_bFromChapter : 1;
+ bool m_bReadonly: 1;
+ bool m_bLevelFromChapter : 1;
+ bool m_bIsAuthSequence :1;
+ bool m_bSortByDocument :1;
//TODO: TemplateNames
//const String* pTemplateName = 0, ???
@@ -67,104 +67,104 @@ class SW_DLLPUBLIC SwTOXDescription
public:
// single argument ctors shall be explicit.
explicit SwTOXDescription(TOXTypes eType) :
- eTOXType(eType),
- pTitle(nullptr),
- pTOUName(nullptr),
- pForm(nullptr),
- nContent(nsSwTOXElement::TOX_MARK | nsSwTOXElement::TOX_OUTLINELEVEL),
- nIndexOptions(nsSwTOIOptions::TOI_SAME_ENTRY|nsSwTOIOptions::TOI_FF|nsSwTOIOptions::TOI_CASE_SENSITIVE),
- nOLEOptions(0),
- eLanguage((LanguageType)::GetAppLanguage()),
- eCaptionDisplay(CAPTION_COMPLETE),
- nLevel(MAXLEVEL),
- bFromObjectNames(false),
- bFromChapter(false),
- bReadonly(true),
- bLevelFromChapter(false),
- bIsAuthSequence(false),
- bSortByDocument(true)
+ m_eTOXType(eType),
+ m_pTitle(nullptr),
+ m_pTOUName(nullptr),
+ m_pForm(nullptr),
+ m_nContent(nsSwTOXElement::TOX_MARK | nsSwTOXElement::TOX_OUTLINELEVEL),
+ m_nIndexOptions(nsSwTOIOptions::TOI_SAME_ENTRY|nsSwTOIOptions::TOI_FF|nsSwTOIOptions::TOI_CASE_SENSITIVE),
+ m_nOLEOptions(0),
+ m_eLanguage((LanguageType)::GetAppLanguage()),
+ m_eCaptionDisplay(CAPTION_COMPLETE),
+ m_nLevel(MAXLEVEL),
+ m_bFromObjectNames(false),
+ m_bFromChapter(false),
+ m_bReadonly(true),
+ m_bLevelFromChapter(false),
+ m_bIsAuthSequence(false),
+ m_bSortByDocument(true)
{}
~SwTOXDescription()
{
- delete pTitle;
- delete pForm;
- delete pTOUName;
+ delete m_pTitle;
+ delete m_pForm;
+ delete m_pTOUName;
}
- TOXTypes GetTOXType() const { return eTOXType;}
+ TOXTypes GetTOXType() const { return m_eTOXType;}
const OUString& GetStyleNames(sal_uInt16 nLvl) const
- {return aStyleNames[nLvl];}
+ {return m_aStyleNames[nLvl];}
void SetStyleNames(const OUString& rSet, sal_uInt16 nLvl)
- {aStyleNames[nLvl] = rSet; }
+ {m_aStyleNames[nLvl] = rSet; }
- const OUString& GetAutoMarkURL() const { return sAutoMarkURL;}
- void SetAutoMarkURL(const OUString& rSet) {sAutoMarkURL = rSet;}
+ const OUString& GetAutoMarkURL() const { return m_sAutoMarkURL;}
+ void SetAutoMarkURL(const OUString& rSet) {m_sAutoMarkURL = rSet;}
- void SetTitle(const OUString& pSet) {delete pTitle; pTitle = new OUString(pSet);}
- const OUString* GetTitle() const {return pTitle; }
+ void SetTitle(const OUString& pSet) {delete m_pTitle; m_pTitle = new OUString(pSet);}
+ const OUString* GetTitle() const {return m_pTitle; }
- void SetTOUName(const OUString& pSet) {delete pTOUName; pTOUName = new OUString(pSet);}
- const OUString* GetTOUName() const {return pTOUName; }
+ void SetTOUName(const OUString& pSet) {delete m_pTOUName; m_pTOUName = new OUString(pSet);}
+ const OUString* GetTOUName() const {return m_pTOUName; }
- void SetForm(const SwForm& rSet) {delete pForm; pForm = new SwForm(rSet);}
- const SwForm* GetForm() const {return pForm;}
+ void SetForm(const SwForm& rSet) {delete m_pForm; m_pForm = new SwForm(rSet);}
+ const SwForm* GetForm() const {return m_pForm;}
- void SetContentOptions(sal_uInt16 nSet) { nContent = nSet;}
- sal_uInt16 GetContentOptions() const { return nContent;}
+ void SetContentOptions(sal_uInt16 nSet) { m_nContent = nSet;}
+ sal_uInt16 GetContentOptions() const { return m_nContent;}
- void SetIndexOptions(sal_uInt16 nSet) { nIndexOptions = nSet;}
- sal_uInt16 GetIndexOptions() const { return nIndexOptions;}
+ void SetIndexOptions(sal_uInt16 nSet) { m_nIndexOptions = nSet;}
+ sal_uInt16 GetIndexOptions() const { return m_nIndexOptions;}
- const OUString& GetMainEntryCharStyle() const {return sMainEntryCharStyle;}
- void SetMainEntryCharStyle(const OUString& rSet) {sMainEntryCharStyle = rSet;}
+ const OUString& GetMainEntryCharStyle() const {return m_sMainEntryCharStyle;}
+ void SetMainEntryCharStyle(const OUString& rSet) {m_sMainEntryCharStyle = rSet;}
- void SetLevel(sal_uInt8 nSet) {nLevel = nSet;}
- sal_uInt8 GetLevel()const {return nLevel; }
+ void SetLevel(sal_uInt8 nSet) {m_nLevel = nSet;}
+ sal_uInt8 GetLevel()const {return m_nLevel; }
- void SetCreateFromObjectNames(bool bSet) { bFromObjectNames = bSet;}
- bool IsCreateFromObjectNames() const {return bFromObjectNames;}
+ void SetCreateFromObjectNames(bool bSet) { m_bFromObjectNames = bSet;}
+ bool IsCreateFromObjectNames() const {return m_bFromObjectNames;}
- const OUString& GetSequenceName() const {return sSequenceName;}
- void SetSequenceName(const OUString& rSet) {sSequenceName = rSet;}
+ const OUString& GetSequenceName() const {return m_sSequenceName;}
+ void SetSequenceName(const OUString& rSet) {m_sSequenceName = rSet;}
- SwCaptionDisplay GetCaptionDisplay() const { return eCaptionDisplay;}
- void SetCaptionDisplay(SwCaptionDisplay eSet) {eCaptionDisplay = eSet;}
+ SwCaptionDisplay GetCaptionDisplay() const { return m_eCaptionDisplay;}
+ void SetCaptionDisplay(SwCaptionDisplay eSet) {m_eCaptionDisplay = eSet;}
- void SetFromChapter(bool bSet) { bFromChapter = bSet;}
- bool IsFromChapter() const {return bFromChapter;}
+ void SetFromChapter(bool bSet) { m_bFromChapter = bSet;}
+ bool IsFromChapter() const {return m_bFromChapter;}
- void SetReadonly(bool bSet){bReadonly = bSet;}
- bool IsReadonly() const {return bReadonly;}
+ void SetReadonly(bool bSet){m_bReadonly = bSet;}
+ bool IsReadonly() const {return m_bReadonly;}
- sal_uInt16 GetOLEOptions() const {return nOLEOptions;}
- void SetOLEOptions(sal_uInt16 nOpt) {nOLEOptions = nOpt;}
+ sal_uInt16 GetOLEOptions() const {return m_nOLEOptions;}
+ void SetOLEOptions(sal_uInt16 nOpt) {m_nOLEOptions = nOpt;}
- bool IsLevelFromChapter() const {return bLevelFromChapter;}
- void SetLevelFromChapter(bool bSet) {bLevelFromChapter = bSet;}
+ bool IsLevelFromChapter() const {return m_bLevelFromChapter;}
+ void SetLevelFromChapter(bool bSet) {m_bLevelFromChapter = bSet;}
- OUString GetAuthBrackets() const {return sAuthBrackets;}
- void SetAuthBrackets(const OUString& rSet) {sAuthBrackets = rSet;}
+ OUString GetAuthBrackets() const {return m_sAuthBrackets;}
+ void SetAuthBrackets(const OUString& rSet) {m_sAuthBrackets = rSet;}
- bool IsAuthSequence() const {return bIsAuthSequence;}
- void SetAuthSequence(bool bSet){bIsAuthSequence = bSet;}
+ bool IsAuthSequence() const {return m_bIsAuthSequence;}
+ void SetAuthSequence(bool bSet){m_bIsAuthSequence = bSet;}
- bool IsSortByDocument()const {return bSortByDocument ;}
- void SetSortByDocument(bool bSet) {bSortByDocument = bSet;}
+ bool IsSortByDocument()const {return m_bSortByDocument ;}
+ void SetSortByDocument(bool bSet) {m_bSortByDocument = bSet;}
void SetSortKeys(SwTOXSortKey eKey1,
SwTOXSortKey eKey2,
SwTOXSortKey eKey3);
- SwTOXSortKey GetSortKey1() const {return eSortKey1;}
- SwTOXSortKey GetSortKey2() const {return eSortKey2;}
- SwTOXSortKey GetSortKey3() const {return eSortKey3;}
+ SwTOXSortKey GetSortKey1() const {return m_eSortKey1;}
+ SwTOXSortKey GetSortKey2() const {return m_eSortKey2;}
+ SwTOXSortKey GetSortKey3() const {return m_eSortKey3;}
- LanguageType GetLanguage() const {return eLanguage;}
- void SetLanguage(LanguageType nLang) {eLanguage = nLang;}
+ LanguageType GetLanguage() const {return m_eLanguage;}
+ void SetLanguage(LanguageType nLang) {m_eLanguage = nLang;}
- const OUString& GetSortAlgorithm()const {return sSortAlgorithm;}
- void SetSortAlgorithm(const OUString& rSet) {sSortAlgorithm = rSet;}
+ const OUString& GetSortAlgorithm()const {return m_sSortAlgorithm;}
+ void SetSortAlgorithm(const OUString& rSet) {m_sSortAlgorithm = rSet;}
void ApplyTo(SwTOXBase& rTOXBase);
diff --git a/sw/source/uibase/index/toxmgr.cxx b/sw/source/uibase/index/toxmgr.cxx
index 1e309ff..6ea8f85 100644
--- a/sw/source/uibase/index/toxmgr.cxx
+++ b/sw/source/uibase/index/toxmgr.cxx
@@ -471,9 +471,9 @@ void SwTOXDescription::SetSortKeys(SwTOXSortKey eKey1,
if(AUTH_FIELD_END > eKey3.eField)
aArr[nPos++] = eKey3;
- eSortKey1 = aArr[0];
- eSortKey2 = aArr[1];
- eSortKey3 = aArr[2];
+ m_eSortKey1 = aArr[0];
+ m_eSortKey2 = aArr[1];
+ m_eSortKey3 = aArr[2];
}
void SwTOXDescription::ApplyTo(SwTOXBase& rTOXBase)
@@ -494,8 +494,8 @@ void SwTOXDescription::ApplyTo(SwTOXBase& rTOXBase)
rTOXBase.SetProtected(IsReadonly());
rTOXBase.SetOLEOptions(GetOLEOptions());
rTOXBase.SetLevelFromChapter(IsLevelFromChapter());
- rTOXBase.SetLanguage(eLanguage);
- rTOXBase.SetSortAlgorithm(sSortAlgorithm);
+ rTOXBase.SetLanguage(m_eLanguage);
+ rTOXBase.SetSortAlgorithm(m_sSortAlgorithm);
}
commit 4c490390e852379da75f2749fc1b7621db04e7cb
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date: Wed Nov 11 08:53:43 2015 +0100
sw: prefix members of SwRedlineAcceptDlg
Change-Id: I88954e88dce974a657575a23706d7ee9542ab530
diff --git a/sw/source/uibase/inc/redlndlg.hxx b/sw/source/uibase/inc/redlndlg.hxx
index 7180373..5044e07 100644
--- a/sw/source/uibase/inc/redlndlg.hxx
+++ b/sw/source/uibase/inc/redlndlg.hxx
@@ -63,38 +63,38 @@ typedef std::vector<std::unique_ptr<SwRedlineDataChild>> SwRedlineDataChildArr;
class SW_DLLPUBLIC SwRedlineAcceptDlg
{
- VclPtr<vcl::Window> pParentDlg;
+ VclPtr<vcl::Window> m_pParentDlg;
std::vector<std::unique_ptr<SwRedlineDataParent>> m_RedlineParents;
SwRedlineDataChildArr m_RedlineChildren;
- SwRedlineDataParentSortArr aUsedSeqNo;
- VclPtr<SvxAcceptChgCtr> aTabPagesCTRL;
- PopupMenu aPopup;
- Timer aDeselectTimer;
- Timer aSelectTimer;
- OUString sInserted;
- OUString sDeleted;
- OUString sFormated;
- OUString sTableChgd;
- OUString sFormatCollSet;
- OUString sFilterAction;
- OUString sAutoFormat;
- VclPtr<SvxTPView> pTPView;
- VclPtr<SvxRedlinTable> pTable; // PB 2006/02/02 #i48648 now SvHeaderTabListBox
- Link<SvTreeListBox*,void> aOldSelectHdl;
- Link<SvTreeListBox*,void> aOldDeselectHdl;
- bool bOnlyFormatedRedlines;
- bool bHasReadonlySel;
- bool bRedlnAutoFormat;
+ SwRedlineDataParentSortArr m_aUsedSeqNo;
+ VclPtr<SvxAcceptChgCtr> m_aTabPagesCTRL;
+ PopupMenu m_aPopup;
+ Timer m_aDeselectTimer;
+ Timer m_aSelectTimer;
+ OUString m_sInserted;
+ OUString m_sDeleted;
+ OUString m_sFormated;
+ OUString m_sTableChgd;
+ OUString m_sFormatCollSet;
+ OUString m_sFilterAction;
+ OUString m_sAutoFormat;
+ VclPtr<SvxTPView> m_pTPView;
+ VclPtr<SvxRedlinTable> m_pTable; // PB 2006/02/02 #i48648 now SvHeaderTabListBox
+ Link<SvTreeListBox*,void> m_aOldSelectHdl;
+ Link<SvTreeListBox*,void> m_aOldDeselectHdl;
+ bool m_bOnlyFormatedRedlines;
+ bool m_bHasReadonlySel;
+ bool m_bRedlnAutoFormat;
// prevent update dialog data during longer operations (cf #102657#)
- bool bInhibitActivate;
+ bool m_bInhibitActivate;
- Image aInserted;
- Image aDeleted;
- Image aFormated;
- Image aTableChgd;
- Image aFormatCollSet;
- Image aAutoFormat;
+ Image m_aInserted;
+ Image m_aDeleted;
+ Image m_aFormated;
+ Image m_aTableChgd;
+ Image m_aFormatCollSet;
+ Image m_aAutoFormat;
DECL_DLLPRIVATE_LINK_TYPED( AcceptHdl, SvxTPView*, void );
DECL_DLLPRIVATE_LINK_TYPED( AcceptAllHdl, SvxTPView*, void );
@@ -127,8 +127,8 @@ public:
DECL_LINK_TYPED( FilterChangedHdl, SvxTPFilter*, void );
- inline SvxAcceptChgCtr& GetChgCtrl() { return *aTabPagesCTRL.get(); }
- inline bool HasRedlineAutoFormat() const { return bRedlnAutoFormat; }
+ inline SvxAcceptChgCtr& GetChgCtrl() { return *m_aTabPagesCTRL.get(); }
+ inline bool HasRedlineAutoFormat() const { return m_bRedlnAutoFormat; }
void Init(sal_uInt16 nStart = 0);
void CallAcceptReject( bool bSelect, bool bAccept );
diff --git a/sw/source/uibase/misc/redlndlg.cxx b/sw/source/uibase/misc/redlndlg.cxx
index 694b7b0..c1aaf36 100644
--- a/sw/source/uibase/misc/redlndlg.cxx
+++ b/sw/source/uibase/misc/redlndlg.cxx
@@ -148,100 +148,100 @@ void SwModelessRedlineAcceptDlg::dispose()
SwRedlineAcceptDlg::SwRedlineAcceptDlg(vcl::Window *pParent, VclBuilderContainer *pBuilder,
vcl::Window *pContentArea, bool bAutoFormat) :
- pParentDlg (pParent),
- aTabPagesCTRL (VclPtr<SvxAcceptChgCtr>::Create(pContentArea, pBuilder)),
- aPopup (SW_RES(MN_REDLINE_POPUP)),
- sInserted (SW_RES(STR_REDLINE_INSERTED)),
- sDeleted (SW_RES(STR_REDLINE_DELETED)),
- sFormated (SW_RES(STR_REDLINE_FORMATED)),
- sTableChgd (SW_RES(STR_REDLINE_TABLECHG)),
- sFormatCollSet (SW_RES(STR_REDLINE_FMTCOLLSET)),
- sAutoFormat (SW_RES(STR_REDLINE_AUTOFMT)),
- bOnlyFormatedRedlines( false ),
- bHasReadonlySel ( false ),
- bRedlnAutoFormat (bAutoFormat),
- bInhibitActivate( false ),
- aInserted (SW_RES(IMG_REDLINE_INSERTED)),
- aDeleted (SW_RES(IMG_REDLINE_DELETED)),
- aFormated (SW_RES(IMG_REDLINE_FORMATED)),
- aTableChgd (SW_RES(IMG_REDLINE_TABLECHG)),
- aFormatCollSet (SW_RES(IMG_REDLINE_FMTCOLLSET)),
- aAutoFormat (SW_RES(IMG_REDLINE_AUTOFMT))
+ m_pParentDlg (pParent),
+ m_aTabPagesCTRL (VclPtr<SvxAcceptChgCtr>::Create(pContentArea, pBuilder)),
+ m_aPopup (SW_RES(MN_REDLINE_POPUP)),
+ m_sInserted (SW_RES(STR_REDLINE_INSERTED)),
+ m_sDeleted (SW_RES(STR_REDLINE_DELETED)),
+ m_sFormated (SW_RES(STR_REDLINE_FORMATED)),
+ m_sTableChgd (SW_RES(STR_REDLINE_TABLECHG)),
+ m_sFormatCollSet (SW_RES(STR_REDLINE_FMTCOLLSET)),
+ m_sAutoFormat (SW_RES(STR_REDLINE_AUTOFMT)),
+ m_bOnlyFormatedRedlines( false ),
+ m_bHasReadonlySel ( false ),
+ m_bRedlnAutoFormat (bAutoFormat),
+ m_bInhibitActivate( false ),
+ m_aInserted (SW_RES(IMG_REDLINE_INSERTED)),
+ m_aDeleted (SW_RES(IMG_REDLINE_DELETED)),
+ m_aFormated (SW_RES(IMG_REDLINE_FORMATED)),
+ m_aTableChgd (SW_RES(IMG_REDLINE_TABLECHG)),
+ m_aFormatCollSet (SW_RES(IMG_REDLINE_FMTCOLLSET)),
+ m_aAutoFormat (SW_RES(IMG_REDLINE_AUTOFMT))
{
- aTabPagesCTRL->SetHelpId(HID_REDLINE_CTRL);
- pTPView = aTabPagesCTRL->GetViewPage();
+ m_aTabPagesCTRL->SetHelpId(HID_REDLINE_CTRL);
+ m_pTPView = m_aTabPagesCTRL->GetViewPage();
- pTable = pTPView->GetTableControl();
+ m_pTable = m_pTPView->GetTableControl();
- pTPView->InsertWriterHeader();
- pTPView->SetAcceptClickHdl(LINK(this, SwRedlineAcceptDlg, AcceptHdl));
- pTPView->SetAcceptAllClickHdl(LINK(this, SwRedlineAcceptDlg, AcceptAllHdl));
- pTPView->SetRejectClickHdl(LINK(this, SwRedlineAcceptDlg, RejectHdl));
- pTPView->SetRejectAllClickHdl(LINK(this, SwRedlineAcceptDlg, RejectAllHdl));
- pTPView->SetUndoClickHdl(LINK(this, SwRedlineAcceptDlg, UndoHdl));
+ m_pTPView->InsertWriterHeader();
+ m_pTPView->SetAcceptClickHdl(LINK(this, SwRedlineAcceptDlg, AcceptHdl));
+ m_pTPView->SetAcceptAllClickHdl(LINK(this, SwRedlineAcceptDlg, AcceptAllHdl));
+ m_pTPView->SetRejectClickHdl(LINK(this, SwRedlineAcceptDlg, RejectHdl));
+ m_pTPView->SetRejectAllClickHdl(LINK(this, SwRedlineAcceptDlg, RejectAllHdl));
+ m_pTPView->SetUndoClickHdl(LINK(this, SwRedlineAcceptDlg, UndoHdl));
//tdf#89227 default to disabled, and only enable if possible to accept/reject
- pTPView->EnableAccept(false);
- pTPView->EnableReject(false);
- pTPView->EnableAcceptAll(false);
- pTPView->EnableRejectAll(false);
+ m_pTPView->EnableAccept(false);
+ m_pTPView->EnableReject(false);
+ m_pTPView->EnableAcceptAll(false);
+ m_pTPView->EnableRejectAll(false);
- aTabPagesCTRL->GetFilterPage()->SetReadyHdl(LINK(this, SwRedlineAcceptDlg, FilterChangedHdl));
+ m_aTabPagesCTRL->GetFilterPage()->SetReadyHdl(LINK(this, SwRedlineAcceptDlg, FilterChangedHdl));
- ListBox *pActLB = aTabPagesCTRL->GetFilterPage()->GetLbAction();
- pActLB->InsertEntry(sInserted);
- pActLB->InsertEntry(sDeleted);
- pActLB->InsertEntry(sFormated);
- pActLB->InsertEntry(sTableChgd);
+ ListBox *pActLB = m_aTabPagesCTRL->GetFilterPage()->GetLbAction();
+ pActLB->InsertEntry(m_sInserted);
+ pActLB->InsertEntry(m_sDeleted);
+ pActLB->InsertEntry(m_sFormated);
+ pActLB->InsertEntry(m_sTableChgd);
if (HasRedlineAutoFormat())
{
- pActLB->InsertEntry(sFormatCollSet);
- pActLB->InsertEntry(sAutoFormat);
- pTPView->ShowUndo();
- pTPView->DisableUndo(); // no UNDO events yet
+ pActLB->InsertEntry(m_sFormatCollSet);
+ pActLB->InsertEntry(m_sAutoFormat);
+ m_pTPView->ShowUndo();
+ m_pTPView->DisableUndo(); // no UNDO events yet
}
pActLB->SelectEntryPos(0);
- pTable->SetStyle(pTable->GetStyle()|WB_HASLINES|WB_CLIPCHILDREN|WB_HASBUTTONS|WB_HASBUTTONSATROOT|WB_HSCROLL);
- pTable->SetNodeDefaultImages();
- pTable->SetSelectionMode(MULTIPLE_SELECTION);
- pTable->SetHighlightRange(1);
+ m_pTable->SetStyle(m_pTable->GetStyle()|WB_HASLINES|WB_CLIPCHILDREN|WB_HASBUTTONS|WB_HASBUTTONSATROOT|WB_HSCROLL);
+ m_pTable->SetNodeDefaultImages();
+ m_pTable->SetSelectionMode(MULTIPLE_SELECTION);
+ m_pTable->SetHighlightRange(1);
- pTable->SortByCol(nSortMode, bSortDir);
+ m_pTable->SortByCol(nSortMode, bSortDir);
- aOldSelectHdl = pTable->GetSelectHdl();
- aOldDeselectHdl = pTable->GetDeselectHdl();
- pTable->SetSelectHdl(LINK(this, SwRedlineAcceptDlg, SelectHdl));
- pTable->SetDeselectHdl(LINK(this, SwRedlineAcceptDlg, DeselectHdl));
- pTable->SetCommandHdl(LINK(this, SwRedlineAcceptDlg, CommandHdl));
+ m_aOldSelectHdl = m_pTable->GetSelectHdl();
+ m_aOldDeselectHdl = m_pTable->GetDeselectHdl();
+ m_pTable->SetSelectHdl(LINK(this, SwRedlineAcceptDlg, SelectHdl));
+ m_pTable->SetDeselectHdl(LINK(this, SwRedlineAcceptDlg, DeselectHdl));
+ m_pTable->SetCommandHdl(LINK(this, SwRedlineAcceptDlg, CommandHdl));
// avoid flickering of buttons:
- aDeselectTimer.SetTimeout(100);
- aDeselectTimer.SetTimeoutHdl(LINK(this, SwRedlineAcceptDlg, SelectTimerHdl));
+ m_aDeselectTimer.SetTimeout(100);
+ m_aDeselectTimer.SetTimeoutHdl(LINK(this, SwRedlineAcceptDlg, SelectTimerHdl));
// avoid multiple selection of the same texts:
- aSelectTimer.SetTimeout(100);
- aSelectTimer.SetTimeoutHdl(LINK(this, SwRedlineAcceptDlg, GotoHdl));
+ m_aSelectTimer.SetTimeout(100);
+ m_aSelectTimer.SetTimeoutHdl(LINK(this, SwRedlineAcceptDlg, GotoHdl));
}
SwRedlineAcceptDlg::~SwRedlineAcceptDlg()
{
- aTabPagesCTRL.disposeAndClear();
+ m_aTabPagesCTRL.disposeAndClear();
}
void SwRedlineAcceptDlg::Init(sal_uInt16 nStart)
{
SwWait aWait( *::GetActiveView()->GetDocShell(), false );
- pTable->SetUpdateMode(false);
- aUsedSeqNo.clear();
+ m_pTable->SetUpdateMode(false);
+ m_aUsedSeqNo.clear();
if (nStart)
RemoveParents(nStart, m_RedlineParents.size() - 1);
else
{
- pTable->Clear();
+ m_pTable->Clear();
m_RedlineChildren.clear();
m_RedlineParents.erase(m_RedlineParents.begin() + nStart, m_RedlineParents.end());
}
@@ -250,21 +250,21 @@ void SwRedlineAcceptDlg::Init(sal_uInt16 nStart)
InsertParents(nStart);
InitAuthors();
- pTable->SetUpdateMode(true);
+ m_pTable->SetUpdateMode(true);
// #i69618# this moves the list box to the right position, visually
- SvTreeListEntry* pSelEntry = pTable->FirstSelected();
+ SvTreeListEntry* pSelEntry = m_pTable->FirstSelected();
if( pSelEntry )
- pTable->MakeVisible( pSelEntry, true ); //#i70937#, force the scroll
+ m_pTable->MakeVisible( pSelEntry, true ); //#i70937#, force the scroll
}
void SwRedlineAcceptDlg::InitAuthors()
{
SwWrtShell* pSh = ::GetActiveView()->GetWrtShellPtr();
- if (!aTabPagesCTRL)
+ if (!m_aTabPagesCTRL)
return;
- SvxTPFilter *pFilterPage = aTabPagesCTRL->GetFilterPage();
+ SvxTPFilter *pFilterPage = m_aTabPagesCTRL->GetFilterPage();
std::vector<OUString> aStrings;
OUString sOldAuthor(pFilterPage->GetSelectedAuthor());
@@ -272,8 +272,8 @@ void SwRedlineAcceptDlg::InitAuthors()
sal_uInt16 nCount = pSh->GetRedlineCount();
- bOnlyFormatedRedlines = true;
- bHasReadonlySel = false;
+ m_bOnlyFormatedRedlines = true;
+ m_bHasReadonlySel = false;
bool bIsNotFormated = false;
sal_uInt16 i;
@@ -282,8 +282,8 @@ void SwRedlineAcceptDlg::InitAuthors()
{
const SwRangeRedline& rRedln = pSh->GetRedline(i);
- if( bOnlyFormatedRedlines && nsRedlineType_t::REDLINE_FORMAT != rRedln.GetType() )
- bOnlyFormatedRedlines = false;
+ if( m_bOnlyFormatedRedlines && nsRedlineType_t::REDLINE_FORMAT != rRedln.GetType() )
+ m_bOnlyFormatedRedlines = false;
aStrings.push_back(rRedln.GetAuthorString());
@@ -302,10 +302,10 @@ void SwRedlineAcceptDlg::InitAuthors()
if (pFilterPage->SelectAuthor(sOldAuthor) == LISTBOX_ENTRY_NOTFOUND && !aStrings.empty())
pFilterPage->SelectAuthor(aStrings[0]);
- bool bEnable = pTable->GetEntryCount() != 0 && !pSh->getIDocumentRedlineAccess().GetRedlinePassword().getLength();
- bool bSel = pTable->FirstSelected() != nullptr;
+ bool bEnable = m_pTable->GetEntryCount() != 0 && !pSh->getIDocumentRedlineAccess().GetRedlinePassword().getLength();
+ bool bSel = m_pTable->FirstSelected() != nullptr;
- SvTreeListEntry* pSelEntry = pTable->FirstSelected();
+ SvTreeListEntry* pSelEntry = m_pTable->FirstSelected();
while (pSelEntry)
{
// find the selected redline
@@ -317,14 +317,14 @@ void SwRedlineAcceptDlg::InitAuthors()
bIsNotFormated |= nsRedlineType_t::REDLINE_FORMAT != rRedln.GetType();
}
- pSelEntry = pTable->NextSelected(pSelEntry);
+ pSelEntry = m_pTable->NextSelected(pSelEntry);
}
- pTPView->EnableAccept( bEnable && bSel );
- pTPView->EnableReject( bEnable && bIsNotFormated && bSel );
- pTPView->EnableAcceptAll( bEnable && !bHasReadonlySel );
- pTPView->EnableRejectAll( bEnable && !bHasReadonlySel &&
- !bOnlyFormatedRedlines );
+ m_pTPView->EnableAccept( bEnable && bSel );
+ m_pTPView->EnableReject( bEnable && bIsNotFormated && bSel );
+ m_pTPView->EnableAcceptAll( bEnable && !m_bHasReadonlySel );
+ m_pTPView->EnableRejectAll( bEnable && !m_bHasReadonlySel &&
+ !m_bOnlyFormatedRedlines );
}
OUString SwRedlineAcceptDlg::GetRedlineText(const SwRangeRedline& rRedln, DateTime &rDateTime, sal_uInt16 nStack)
@@ -347,12 +347,12 @@ Image SwRedlineAcceptDlg::GetActionImage(const SwRangeRedline& rRedln, sal_uInt1
{
switch (rRedln.GetType(nStack))
{
- case nsRedlineType_t::REDLINE_INSERT: return aInserted;
- case nsRedlineType_t::REDLINE_DELETE: return aDeleted;
- case nsRedlineType_t::REDLINE_FORMAT: return aFormated;
- case nsRedlineType_t::REDLINE_PARAGRAPH_FORMAT: return aFormated;
- case nsRedlineType_t::REDLINE_TABLE: return aTableChgd;
- case nsRedlineType_t::REDLINE_FMTCOLL: return aFormatCollSet;
+ case nsRedlineType_t::REDLINE_INSERT: return m_aInserted;
+ case nsRedlineType_t::REDLINE_DELETE: return m_aDeleted;
+ case nsRedlineType_t::REDLINE_FORMAT: return m_aFormated;
+ case nsRedlineType_t::REDLINE_PARAGRAPH_FORMAT: return m_aFormated;
+ case nsRedlineType_t::REDLINE_TABLE: return m_aTableChgd;
+ case nsRedlineType_t::REDLINE_FMTCOLL: return m_aFormatCollSet;
}
return Image();
@@ -362,12 +362,12 @@ OUString SwRedlineAcceptDlg::GetActionText(const SwRangeRedline& rRedln, sal_uIn
{
switch( rRedln.GetType(nStack) )
{
- case nsRedlineType_t::REDLINE_INSERT: return sInserted;
- case nsRedlineType_t::REDLINE_DELETE: return sDeleted;
- case nsRedlineType_t::REDLINE_FORMAT: return sFormated;
- case nsRedlineType_t::REDLINE_PARAGRAPH_FORMAT: return sFormated;
- case nsRedlineType_t::REDLINE_TABLE: return sTableChgd;
- case nsRedlineType_t::REDLINE_FMTCOLL: return sFormatCollSet;
+ case nsRedlineType_t::REDLINE_INSERT: return m_sInserted;
+ case nsRedlineType_t::REDLINE_DELETE: return m_sDeleted;
+ case nsRedlineType_t::REDLINE_FORMAT: return m_sFormated;
+ case nsRedlineType_t::REDLINE_PARAGRAPH_FORMAT: return m_sFormated;
+ case nsRedlineType_t::REDLINE_TABLE: return m_sTableChgd;
+ case nsRedlineType_t::REDLINE_FMTCOLL: return m_sFormatCollSet;
default:;//prevent warning
}
@@ -378,22 +378,22 @@ OUString SwRedlineAcceptDlg::GetActionText(const SwRangeRedline& rRedln, sal_uIn
void SwRedlineAcceptDlg::Activate()
{
// prevent update if flag is set (#102547#)
- if( bInhibitActivate )
+ if( m_bInhibitActivate )
return;
SwView *pView = ::GetActiveView();
if (!pView) // can happen when switching to another app
{
- pTPView->EnableAccept(false);
- pTPView->EnableReject(false);
- pTPView->EnableAcceptAll(false);
- pTPView->EnableRejectAll(false);
+ m_pTPView->EnableAccept(false);
+ m_pTPView->EnableReject(false);
+ m_pTPView->EnableAcceptAll(false);
+ m_pTPView->EnableRejectAll(false);
return; // had the focus previously
}
SwWait aWait( *pView->GetDocShell(), false );
- aUsedSeqNo.clear();
+ m_aUsedSeqNo.clear();
// did something change?
SwWrtShell* pSh = pView->GetWrtShellPtr();
@@ -468,7 +468,7 @@ void SwRedlineAcceptDlg::Activate()
{
// update only comment
OUString sComment(rRedln.GetComment());
- pTable->SetEntryText(sComment.replace('\n', ' '), pParent->pTLBParent, 3);
+ m_pTable->SetEntryText(sComment.replace('\n', ' '), pParent->pTLBParent, 3);
}
pParent->sComment = rRedln.GetComment();
}
@@ -485,7 +485,7 @@ sal_uInt16 SwRedlineAcceptDlg::CalcDiff(sal_uInt16 nStart, bool bChild)
return USHRT_MAX;
}
- pTable->SetUpdateMode(false);
+ m_pTable->SetUpdateMode(false);
SwView *pView = ::GetActiveView();
SwWrtShell* pSh = pView->GetWrtShellPtr();
sal_uInt16 nAutoFormat = HasRedlineAutoFormat() ? nsRedlineType_t::REDLINE_FORM_AUTOFMT : 0;
@@ -502,7 +502,7 @@ sal_uInt16 SwRedlineAcceptDlg::CalcDiff(sal_uInt16 nStart, bool bChild)
{
pNext = const_cast<SwRedlineDataChild*>(pBackupData->pNext);
if (pBackupData->pTLBChild)
- pTable->RemoveEntry(pBackupData->pTLBChild);
+ m_pTable->RemoveEntry(pBackupData->pTLBChild);
for (SwRedlineDataChildArr::iterator it = m_RedlineChildren.begin();
it != m_RedlineChildren.end(); ++it)
@@ -520,7 +520,7 @@ sal_uInt16 SwRedlineAcceptDlg::CalcDiff(sal_uInt16 nStart, bool bChild)
// insert new children
InsertChildren(pParent, rRedln, nAutoFormat);
- pTable->SetUpdateMode(true);
+ m_pTable->SetUpdateMode(true);
return nStart;
}
@@ -532,7 +532,7 @@ sal_uInt16 SwRedlineAcceptDlg::CalcDiff(sal_uInt16 nStart, bool bChild)
{
// remove entries from nStart to i-1
RemoveParents(nStart, i - 1);
- pTable->SetUpdateMode(true);
+ m_pTable->SetUpdateMode(true);
return nStart - 1;
}
}
@@ -547,12 +547,12 @@ sal_uInt16 SwRedlineAcceptDlg::CalcDiff(sal_uInt16 nStart, bool bChild)
{
// insert entries from nStart to i-1
InsertParents(nStart, i - 1);
- pTable->SetUpdateMode(true);
+ m_pTable->SetUpdateMode(true);
return nStart - 1;
}
}
- pTable->SetUpdateMode(true);
+ m_pTable->SetUpdateMode(true);
Init(nStart); // adjust all entries until the end
return USHRT_MAX;
}
@@ -565,22 +565,22 @@ void SwRedlineAcceptDlg::InsertChildren(SwRedlineDataParent *pParent, const SwRa
bool bAutoFormat = (rRedln.GetRealType() & nAutoFormat) != 0;
OUString sAction = GetActionText(rRedln);
- bool bValidParent = sFilterAction.isEmpty() || sFilterAction == sAction;
- bValidParent = bValidParent && pTable->IsValidEntry(rRedln.GetAuthorString(), rRedln.GetTimeStamp(), rRedln.GetComment());
+ bool bValidParent = m_sFilterAction.isEmpty() || m_sFilterAction == sAction;
+ bValidParent = bValidParent && m_pTable->IsValidEntry(rRedln.GetAuthorString(), rRedln.GetTimeStamp(), rRedln.GetComment());
if (nAutoFormat)
{
if (pParent->pData->GetSeqNo())
{
std::pair<SwRedlineDataParentSortArr::const_iterator,bool> const ret
- = aUsedSeqNo.insert(pParent);
+ = m_aUsedSeqNo.insert(pParent);
if (ret.second) // already there
{
if (pParent->pTLBParent)
{
- pTable->SetEntryText(
- sAutoFormat, (*ret.first)->pTLBParent, 0);
- pTable->RemoveEntry(pParent->pTLBParent);
+ m_pTable->SetEntryText(
+ m_sAutoFormat, (*ret.first)->pTLBParent, 0);
... etc. - the rest is truncated
More information about the Libreoffice-commits
mailing list
diff --git a/sw/source/filter/ww8/ww8par2.cxx b/sw/source/filter/ww8/ww8par2.cxx
index f774d41..7f692bc 100644
--- a/sw/source/filter/ww8/ww8par2.cxx
+++ b/sw/source/filter/ww8/ww8par2.cxx
@@ -477,7 +477,7 @@ ApoTestResults SwWW8ImplReader::TestApo(int nCellLevel, bool bTableRowEnd,
// Frame in Style Definition (word appears to ignore them if inside an
// text autoshape)
if (!m_bTxbxFlySection && m_nAktColl < m_vColl.size())
- aRet.mpStyleApo = StyleExists(m_nAktColl) ? m_vColl[m_nAktColl].pWWFly : nullptr;
+ aRet.mpStyleApo = StyleExists(m_nAktColl) ? m_vColl[m_nAktColl].m_pWWFly : nullptr;
/*
#i1140#
@@ -783,7 +783,7 @@ void SwWW8ImplReader::Read_ANLevelNo( sal_uInt16, const sal_uInt8* pData, short
// only for SwTextFormatColl, not CharFormat
// WW: 0 = no Numbering
SwWW8StyInf * pColl = GetStyle(m_nAktColl);
- if (pColl != nullptr && pColl->bColl && *pData)
+ if (pColl != nullptr && pColl->m_bColl && *pData)
{
// Range WW:1..9 -> SW:0..8 no bullets / numbering
@@ -818,7 +818,7 @@ void SwWW8ImplReader::Read_ANLevelDesc( sal_uInt16, const sal_uInt8* pData, shor
{
SwWW8StyInf * pStyInf = GetStyle(m_nAktColl);
if( !m_pAktColl || nLen <= 0 // only for Styledef
- || (pStyInf && !pStyInf->bColl) // ignore CharFormat ->
+ || (pStyInf && !pStyInf->m_bColl) // ignore CharFormat ->
|| ( m_nIniFlags & WW8FL_NO_OUTLINE ) )
{
m_nSwNumLevel = 0xff;
@@ -848,7 +848,7 @@ void SwWW8ImplReader::Read_ANLevelDesc( sal_uInt16, const sal_uInt8* pData, shor
pStyInf = GetStyle(m_nAktColl);
if (pStyInf != nullptr)
- pStyInf->bHasStyNumRule = true;
+ pStyInf->m_bHasStyNumRule = true;
}
}
@@ -956,9 +956,9 @@ void SwWW8ImplReader::StartAnl(const sal_uInt8* pSprm13)
}
SwWW8StyInf * pStyInf = GetStyle(m_nAktColl);
- if (sNumRule.isEmpty() && pStyInf != nullptr && pStyInf->bHasStyNumRule)
+ if (sNumRule.isEmpty() && pStyInf != nullptr && pStyInf->m_bHasStyNumRule)
{
- sNumRule = pStyInf->pFormat->GetNumRule().GetValue();
+ sNumRule = pStyInf->m_pFormat->GetNumRule().GetValue();
pNumRule = m_rDoc.FindNumRulePtr(sNumRule);
if (!pNumRule)
sNumRule.clear();
@@ -3527,8 +3527,8 @@ sal_uInt16 SwWW8ImplReader::StyleUsingLFO( sal_uInt16 nLFOIndex ) const
if( !m_vColl.empty() )
{
for(sal_uInt16 nI = 0; nI < m_pStyles->GetCount(); nI++ )
- if( m_vColl[ nI ].bValid
- && (nLFOIndex == m_vColl[ nI ].nLFOIndex) )
+ if( m_vColl[ nI ].m_bValid
+ && (nLFOIndex == m_vColl[ nI ].m_nLFOIndex) )
nRes = nI;
}
return nRes;
@@ -3540,10 +3540,10 @@ const SwFormat* SwWW8ImplReader::GetStyleWithOrgWWName( OUString& rName ) const
if( !m_vColl.empty() )
{
for(sal_uInt16 nI = 0; nI < m_pStyles->GetCount(); nI++ )
- if( m_vColl[ nI ].bValid
+ if( m_vColl[ nI ].m_bValid
&& (rName.equals( m_vColl[ nI ].GetOrgWWName())) )
{
- pRet = m_vColl[ nI ].pFormat;
+ pRet = m_vColl[ nI ].m_pFormat;
break;
}
}
@@ -3743,7 +3743,7 @@ bool WW8RStyle::PrepareStyle(SwWW8StyInf &rSI, ww::sti eSti, sal_uInt16 nThisSty
SwFormat* pColl;
bool bStyExist;
- if (rSI.bColl)
+ if (rSI.m_bColl)
{
// Para-Style
sw::util::ParaStyleMapper::StyleResult aResult =
@@ -3767,7 +3767,7 @@ bool WW8RStyle::PrepareStyle(SwWW8StyInf &rSI, ww::sti eSti, sal_uInt16 nThisSty
bImport = false;
bool bOldNoImp = pIo->m_bNoAttrImport;
- rSI.bImportSkipped = !bImport;
+ rSI.m_bImportSkipped = !bImport;
if( !bImport )
pIo->m_bNoAttrImport = true;
@@ -3780,37 +3780,37 @@ bool WW8RStyle::PrepareStyle(SwWW8StyInf &rSI, ww::sti eSti, sal_uInt16 nThisSty
pColl->SetAuto(false); // suggested by JP
} // but changes the UI
pIo->m_pAktColl = pColl;
- rSI.pFormat = pColl; // remember translation WW->SW
- rSI.bImportSkipped = !bImport;
+ rSI.m_pFormat = pColl; // remember translation WW->SW
+ rSI.m_bImportSkipped = !bImport;
// Set Based on style
- sal_uInt16 j = rSI.nBase;
+ sal_uInt16 j = rSI.m_nBase;
if (j != nThisStyle && j < cstd )
{
SwWW8StyInf* pj = &pIo->m_vColl[j];
- if (rSI.pFormat && pj->pFormat && rSI.bColl == pj->bColl)
+ if (rSI.m_pFormat && pj->m_pFormat && rSI.m_bColl == pj->m_bColl)
{
- rSI.pFormat->SetDerivedFrom( pj->pFormat ); // ok, set Based on
- rSI.eLTRFontSrcCharSet = pj->eLTRFontSrcCharSet;
- rSI.eRTLFontSrcCharSet = pj->eRTLFontSrcCharSet;
- rSI.eCJKFontSrcCharSet = pj->eCJKFontSrcCharSet;
- rSI.n81Flags = pj->n81Flags;
- rSI.n81BiDiFlags = pj->n81BiDiFlags;
+ rSI.m_pFormat->SetDerivedFrom( pj->m_pFormat ); // ok, set Based on
+ rSI.m_eLTRFontSrcCharSet = pj->m_eLTRFontSrcCharSet;
+ rSI.m_eRTLFontSrcCharSet = pj->m_eRTLFontSrcCharSet;
+ rSI.m_eCJKFontSrcCharSet = pj->m_eCJKFontSrcCharSet;
+ rSI.m_n81Flags = pj->m_n81Flags;
+ rSI.m_n81BiDiFlags = pj->m_n81BiDiFlags;
if (!rSI.IsWW8BuiltInHeadingStyle())
{
rSI.mnWW8OutlineLevel = pj->mnWW8OutlineLevel;
}
- rSI.bParaAutoBefore = pj->bParaAutoBefore;
- rSI.bParaAutoAfter = pj->bParaAutoAfter;
+ rSI.m_bParaAutoBefore = pj->m_bParaAutoBefore;
+ rSI.m_bParaAutoAfter = pj->m_bParaAutoAfter;
- if (pj->pWWFly)
- rSI.pWWFly = new WW8FlyPara(pIo->m_bVer67, pj->pWWFly);
+ if (pj->m_pWWFly)
+ rSI.m_pWWFly = new WW8FlyPara(pIo->m_bVer67, pj->m_pWWFly);
}
}
else if( pIo->m_bNewDoc && bStyExist )
- rSI.pFormat->SetDerivedFrom();
+ rSI.m_pFormat->SetDerivedFrom();
- rSI.nFollow = nNextStyle; // remember Follow
+ rSI.m_nFollow = nNextStyle; // remember Follow
pStyRule = nullptr; // recreate if necessary
bTextColChanged = bFontChanged = bCJKFontChanged = bCTLFontChanged =
@@ -3828,7 +3828,7 @@ void WW8RStyle::PostStyle(SwWW8StyInf &rSI, bool bOldNoImp)
pIo->m_nCharFormat = -1;
// If Style basiert auf Nichts oder Basis ignoriert
- if ((rSI.nBase >= cstd || pIo->m_vColl[rSI.nBase].bImportSkipped) && rSI.bColl)
+ if ((rSI.m_nBase >= cstd || pIo->m_vColl[rSI.m_nBase].m_bImportSkipped) && rSI.m_bColl)
{
// If Char-Styles does not work
// -> set hard WW-Defaults
@@ -3851,17 +3851,17 @@ void WW8RStyle::Import1Style( sal_uInt16 nNr )
SwWW8StyInf &rSI = pIo->m_vColl[nNr];
- if( rSI.bImported || !rSI.bValid )
+ if( rSI.m_bImported || !rSI.m_bValid )
return;
- rSI.bImported = true; // set flag now to avoid endless loops
+ rSI.m_bImported = true; // set flag now to avoid endless loops
// valid and not NUL and not yet imported
- if( rSI.nBase < cstd && !pIo->m_vColl[rSI.nBase].bImported )
- Import1Style( rSI.nBase );
+ if( rSI.m_nBase < cstd && !pIo->m_vColl[rSI.m_nBase].m_bImported )
+ Import1Style( rSI.m_nBase );
- pStStrm->Seek( rSI.nFilePos );
+ pStStrm->Seek( rSI.m_nFilePos );
short nSkip, cbStd;
OUString sName;
@@ -3891,7 +3891,7 @@ void WW8RStyle::Import1Style( sal_uInt16 nNr )
//offset
//Import of the Style Contents
- ImportGrupx(nSkip, xStd->sgc == 1, rSI.nFilePos & 1);
+ ImportGrupx(nSkip, xStd->sgc == 1, rSI.m_nFilePos & 1);
PostStyle(rSI, bOldNoImp);
@@ -3904,13 +3904,13 @@ void WW8RStyle::RecursiveReg(sal_uInt16 nNr)
return;
SwWW8StyInf &rSI = pIo->m_vColl[nNr];
- if( rSI.bImported || !rSI.bValid )
+ if( rSI.m_bImported || !rSI.m_bValid )
return;
- rSI.bImported = true;
+ rSI.m_bImported = true;
- if( rSI.nBase < cstd && !pIo->m_vColl[rSI.nBase].bImported )
- RecursiveReg(rSI.nBase);
+ if( rSI.m_nBase < cstd && !pIo->m_vColl[rSI.m_nBase].m_bImported )
+ RecursiveReg(rSI.m_nBase);
pIo->RegisterNumFormatOnStyle(nNr);
@@ -3929,7 +3929,7 @@ void WW8RStyle::PostProcessStyles()
formats and use it to mark handled ones
*/
for (i=0; i < cstd; ++i)
- pIo->m_vColl[i].bImported = false;
+ pIo->m_vColl[i].m_bImported = false;
/*
Register the num formats and tabstop changes on the styles recursively.
@@ -3944,7 +3944,7 @@ void WW8RStyle::PostProcessStyles()
*/
for (i=0; i < cstd; ++i)
{
- if (pIo->m_vColl[i].bValid)
+ if (pIo->m_vColl[i].m_bValid)
{
RecursiveReg(i);
}
@@ -3958,13 +3958,13 @@ void WW8RStyle::ScanStyles() // investigate style dependencies
short nSkip;
SwWW8StyInf &rSI = pIo->m_vColl[i];
- rSI.nFilePos = pStStrm->Tell(); // remember FilePos
+ rSI.m_nFilePos = pStStrm->Tell(); // remember FilePos
WW8_STD* pStd = Read1Style( nSkip, nullptr, nullptr ); // read STD
- rSI.bValid = (nullptr != pStd);
- if (rSI.bValid)
+ rSI.m_bValid = (nullptr != pStd);
+ if (rSI.m_bValid)
{
- rSI.nBase = pStd->istdBase; // remember Basis
- rSI.bColl = ( pStd->sgc == 1 ); // Para-Style
+ rSI.m_nBase = pStd->istdBase; // remember Basis
+ rSI.m_bColl = ( pStd->sgc == 1 ); // Para-Style
}
else
rSI = SwWW8StyInf();
@@ -4213,9 +4213,9 @@ void WW8RStyle::ImportOldFormatStyles()
{
for (sal_uInt16 i=0; i < cstd; ++i)
{
- pIo->m_vColl[i].bColl = true;
+ pIo->m_vColl[i].m_bColl = true;
//every chain must end eventually at the null style (style code 222)
- pIo->m_vColl[i].nBase = 222;
+ pIo->m_vColl[i].m_nBase = 222;
}
rtl_TextEncoding eStructChrSet = WW8Fib::GetFIBCharset(
@@ -4256,7 +4256,7 @@ void WW8RStyle::ImportOldFormatStyles()
nByteCount += aTmp.getLength();
sName = OStringToOUString(aTmp, eStructChrSet);
}
- rSI.bImported = true;
+ rSI.m_bImported = true;
}
if (sName.isEmpty())
@@ -4389,7 +4389,7 @@ void WW8RStyle::ImportOldFormatStyles()
stcBase = 222;
SwWW8StyInf &rSI = pIo->m_vColl[stc];
- rSI.nBase = stcBase;
+ rSI.m_nBase = stcBase;
ww::sti eSti = ww::GetCanonicalStiFromStc(stc);
@@ -4399,10 +4399,10 @@ void WW8RStyle::ImportOldFormatStyles()
if (stcp >= aPAPXOffsets.size())
continue;
- rSI.bValid = true;
+ rSI.m_bValid = true;
if (ww::StandardStiIsCharStyle(eSti) && !aPAPXOffsets[stcp].mnSize)
- pIo->m_vColl[stc].bColl = false;
+ pIo->m_vColl[stc].m_bColl = false;
bool bOldNoImp = PrepareStyle(rSI, eSti, stc, stcNext);
@@ -4423,7 +4423,7 @@ void WW8RStyle::ImportNewFormatStyles()
ScanStyles(); // Scan Based On
for (sal_uInt16 i = 0; i < cstd; ++i) // import Styles
- if (pIo->m_vColl[i].bValid)
+ if (pIo->m_vColl[i].m_bValid)
Import1Style( i );
}
@@ -4450,17 +4450,17 @@ void WW8RStyle::Import()
{
// Follow chain
SwWW8StyInf* pi = &pIo->m_vColl[i];
- sal_uInt16 j = pi->nFollow;
+ sal_uInt16 j = pi->m_nFollow;
if( j < cstd )
{
SwWW8StyInf* pj = &pIo->m_vColl[j];
if ( j != i // rational Index ?
- && pi->pFormat // Format ok ?
- && pj->pFormat // Derived-Format ok ?
- && pi->bColl // only possible for paragraph templates (WW)
- && pj->bColl ){ // identical Typ ?
- static_cast<SwTextFormatColl*>(pi->pFormat)->SetNextTextFormatColl(
- *static_cast<SwTextFormatColl*>(pj->pFormat) ); // ok, register
+ && pi->m_pFormat // Format ok ?
+ && pj->m_pFormat // Derived-Format ok ?
+ && pi->m_bColl // only possible for paragraph templates (WW)
+ && pj->m_bColl ){ // identical Typ ?
+ static_cast<SwTextFormatColl*>(pi->m_pFormat)->SetNextTextFormatColl(
+ *static_cast<SwTextFormatColl*>(pj->m_pFormat) ); // ok, register
}
}
}
@@ -4475,8 +4475,8 @@ void WW8RStyle::Import()
// for e.g. tables an always valid Std-Style is necessary
if( pIo->StyleExists(0) && !pIo->m_vColl.empty() &&
- pIo->m_vColl[0].pFormat && pIo->m_vColl[0].bColl && pIo->m_vColl[0].bValid )
- pIo->m_pDfltTextFormatColl = static_cast<SwTextFormatColl*>(pIo->m_vColl[0].pFormat);
+ pIo->m_vColl[0].m_pFormat && pIo->m_vColl[0].m_bColl && pIo->m_vColl[0].m_bValid )
+ pIo->m_pDfltTextFormatColl = static_cast<SwTextFormatColl*>(pIo->m_vColl[0].m_pFormat);
else
pIo->m_pDfltTextFormatColl = pIo->m_rDoc.GetDfltTextFormatColl();
@@ -4514,16 +4514,16 @@ void WW8RStyle::Import()
rtl_TextEncoding SwWW8StyInf::GetCharSet() const
{
- if ((pFormat) && (pFormat->GetFrmDir().GetValue() == FRMDIR_HORI_RIGHT_TOP))
- return eRTLFontSrcCharSet;
- return eLTRFontSrcCharSet;
+ if ((m_pFormat) && (m_pFormat->GetFrmDir().GetValue() == FRMDIR_HORI_RIGHT_TOP))
+ return m_eRTLFontSrcCharSet;
+ return m_eLTRFontSrcCharSet;
}
rtl_TextEncoding SwWW8StyInf::GetCJKCharSet() const
{
- if ((pFormat) && (pFormat->GetFrmDir().GetValue() == FRMDIR_HORI_RIGHT_TOP))
- return eRTLFontSrcCharSet;
- return eCJKFontSrcCharSet;
+ if ((m_pFormat) && (m_pFormat->GetFrmDir().GetValue() == FRMDIR_HORI_RIGHT_TOP))
+ return m_eRTLFontSrcCharSet;
+ return m_eCJKFontSrcCharSet;
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */